@@ -9,7 +9,7 @@
 #                         and Technology (RIST). All rights reserved.
 # Copyright (c) 2015      IBM Corporation.  All rights reserved.
 #
-# Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+# Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
 # $COPYRIGHT$
 #
 # Additional copyrights may follow
@@ -286,7 +286,7 @@ sub mca_generate_framework_header(\$\@) {
     }
 
     my $ifdef_string = uc "pmix_FRAMEWORKS_H";
-    open(FRAMEWORKS_OUT, ">src/include/frameworks.h");
+    open(FRAMEWORKS_OUT, ">src/include/pmix_frameworks.h");
     printf FRAMEWORKS_OUT "%s", "/*
  * This file is autogenerated by autogen.pl. Do not edit this file by hand.
  */
