@@ -1,7 +1,8 @@
 #
 # Copyright (c) 2020      Intel, Inc.  All rights reserved.
-# Copyright (c) 2020      Cisco Systems, Inc.  All rights reserved
-# Copyright (c) 2021      Nanook Consulting  All rights reserved.
+# Copyright (c) 2020-2022 Cisco Systems, Inc.  All rights reserved
+# Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
+# Copyright (c) 2022      Triad National Security, LLC. All rights reserved.
 # $COPYRIGHT$
 #
 # Construct a dictionary for translating attributes to/from
@@ -10,17 +11,23 @@
 #
 
 from __future__ import print_function
-import os, os.path, sys, shutil
+import os
+import os.path
+import sys
 from optparse import OptionParser, OptionGroup
 
+index = 0
+
+
 def harvest_constants(options, path, constants):
+    global index
     # open the file
     try:
         inputfile = open(path, "r")
     except Exception as e:
         print("File {path} could not be opened: {e}"
               .format(path=path, e=e))
-        return 1
+        return 1, 0
 
     # read the file - these files aren't too large
     # so ingest the whole thing at one gulp
@@ -30,7 +37,7 @@ def harvest_constants(options, path, constants):
         print("Error reading file {path}: {e}"
               .format(path=path, e=e))
         inputfile.close()
-        return 1
+        return 1, 0
 
     inputfile.close()  # we read everything, so done with the file
 
@@ -65,13 +72,14 @@ def harvest_constants(options, path, constants):
                     if not firstline:
                         constants.write(",\n\n")
                     firstline = False
-                    constants.write("    {.name = \"" + tokens[0] + "\", .string = " + tokens[1])
+                    constants.write("    {.index = " + str(index) + ", .name = \"" + tokens[0] + "\", .string = " + tokens[1])
+                    index = index + 1
                     # only one attribute violates the one-word rule for type
                     if tokens[0] == "PMIX_EVENT_BASE":
                         dstart = 3
                         datatype = "PMIX_POINTER"
                     elif tokens[0] == "PMIX_ATTR_UNDEF":
-                        constants.write(", .type = PMIX_POINTER,\n     .description = (char *[]){\"NONE\"}}")
+                        constants.write(", .type = PMIX_POINTER,\n     .description = (char *[]){\"NONE\", NULL}}")
                         continue
                     else:
                         dstart = 4
@@ -230,6 +238,47 @@ def harvest_constants(options, path, constants):
     inputfile.close()
     return 0
 
+
+def _write_header(options, base_path, num_elements):
+    contents = '''/*
+ * This file is autogenerated by construct_dictionary.py.
+ * Do not edit this file by hand.
+ */
+
+#include "src/include/pmix_config.h"
+#include "src/include/pmix_globals.h"
+#include "include/pmix_common.h"
+
+#ifndef PMIX_DICTIONARY_H
+#define PMIX_DICTIONARY_H
+
+BEGIN_C_DECLS
+
+PMIX_EXPORT extern const pmix_regattr_input_t pmix_dictionary[{ne}];
+
+#define PMIX_INDEX_BOUNDARY {nem1}
+
+END_C_DECLS
+
+#endif\n
+'''.format(ne=num_elements, nem1=num_elements - 1)
+
+    if options.dryrun:
+        constants = sys.stdout
+        outpath = None
+    else:
+        outpath = os.path.join(base_path, "pmix_dictionary.h")
+        try:
+            constants = open(outpath, "w+")
+        except Exception as e:
+            print("{outpath} CANNOT BE OPENED - DICTIONARY COULD NOT BE CONSTRUCTED: {e}"
+                  .format(outpath=outpath, e=e))
+            return 1
+    constants.write(contents)
+    constants.close()
+    return 0
+
+
 def main():
     parser = OptionParser("usage: %prog [options]")
     debugGroup = OptionGroup(parser, "Debug Options")
@@ -268,7 +317,7 @@ def main():
         constants = sys.stdout
         outpath = None
     else:
-        outpath = os.path.join(build_src_include_dir, "dictionary.h")
+        outpath = os.path.join(build_src_include_dir, "pmix_dictionary.c")
         try:
             constants = open(outpath, "w+")
         except Exception as e:
@@ -276,16 +325,15 @@ def main():
                   .format(outpath=outpath, e=e))
             return 1
 
-    # write the header
+    # write the source file
     constants.write("""/*
  * This file is autogenerated by construct_dictionary.py.
  * Do not edit this file by hand.
  */
 
-#include "src/include/pmix_config.h"
-#include "src/include/pmix_globals.h"
+#include "src/include/pmix_dictionary.h"
 
-pmix_regattr_input_t dictionary[] = {
+const pmix_regattr_input_t pmix_dictionary[] = {
 """)
 
     # scan across the header files in the src directory
@@ -315,12 +363,16 @@ pmix_regattr_input_t dictionary[] = {
         return 1
 
     # mark the end of the array
-    constants.write(""",
-    {.name = ""}
+    constants.write(""",\n
+    {.index = UINT32_MAX, .name = "", .string = "", .type = PMIX_POINTER, .description = (char *[]){"NONE", NULL}}
 };
 """)
+    constants.write("\n")
     constants.close()
-    return 0
+
+    # write the header
+    return _write_header(options, build_src_include_dir, index + 1)
+
 
 if __name__ == '__main__':
     exit(main())
