@@ -16,7 +16,8 @@
  * Copyright (c) 2013-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Mellanox Technologies, Inc.  All rights reserved.
  * Copyright (c) 2019      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2022      ParTec AG.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -125,7 +126,8 @@ int main(int argc, char **argv)
     pmix_value_t *val = NULL;
     char *tmp;
     pmix_proc_t proc;
-    uint32_t nprocs, n;
+    uint32_t nprocs, n, k, nlocal;
+    bool local, all_local = false;;
     pmix_info_t *info;
     bool flag;
     mylock_t mylock;
@@ -133,6 +135,8 @@ int main(int argc, char **argv)
     pmix_status_t dbg = PMIX_ERR_DEBUGGER_RELEASE;
     pid_t pid;
     pmix_topology_t mytopo;
+    char **peers;
+    pmix_rank_t *locals = NULL;
 
     EXAMPLES_HIDE_UNUSED_PARAMS(argc, argv);
 
@@ -145,8 +149,8 @@ int main(int argc, char **argv)
      * is included, then the process will be stopped in this call until
      * the "debugger release" notification arrives */
     if (PMIX_SUCCESS != (rc = PMIx_Init(&myproc, NULL, 0))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Init failed: %d\n", myproc.nspace, myproc.rank,
-                rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Init failed: %s\n", myproc.nspace, myproc.rank,
+                PMIx_Error_string(rc));
         exit(0);
     }
     fprintf(stderr, "Client ns %s rank %d pid %lu: Running\n", myproc.nspace, myproc.rank,
@@ -215,8 +219,8 @@ int main(int argc, char **argv)
 
     /* get our universe size */
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_UNIV_SIZE, NULL, 0, &val))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Get universe size failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Get universe size failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     fprintf(stderr, "Client %s:%d universe size %d\n", myproc.nspace, myproc.rank,
@@ -226,8 +230,8 @@ int main(int argc, char **argv)
     /* get the number of procs in our job - univ size is the total number of allocated
      * slots, not the number of procs in the job */
     if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_JOB_SIZE, NULL, 0, &val))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Get job size failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Get job size failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     nprocs = val->data.uint32;
@@ -242,8 +246,8 @@ int main(int argc, char **argv)
     value.type = PMIX_UINT32;
     value.data.uint32 = 1234;
     if (PMIX_SUCCESS != (rc = PMIx_Store_internal(&myproc, tmp, &value))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Store_internal failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Store_internal failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     free(tmp);
@@ -254,8 +258,8 @@ int main(int argc, char **argv)
     value.type = PMIX_UINT64;
     value.data.uint64 = 1234;
     if (PMIX_SUCCESS != (rc = PMIx_Put(PMIX_LOCAL, tmp, &value))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Put internal failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Put internal failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     free(tmp);
@@ -266,16 +270,16 @@ int main(int argc, char **argv)
     value.type = PMIX_STRING;
     value.data.string = "1234";
     if (PMIX_SUCCESS != (rc = PMIx_Put(PMIX_REMOTE, tmp, &value))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Put internal failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Put internal failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     free(tmp);
 
     /* push the data to our PMIx server */
     if (PMIX_SUCCESS != (rc = PMIx_Commit())) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Commit failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Commit failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
         goto done;
     }
     if (0 == myproc.rank) {
@@ -289,76 +293,113 @@ int main(int argc, char **argv)
     flag = true;
     PMIX_INFO_LOAD(info, PMIX_COLLECT_DATA, &flag, PMIX_BOOL);
     if (PMIX_SUCCESS != (rc = PMIx_Fence(&proc, 1, info, 1))) {
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Fence failed: %d\n", myproc.nspace, myproc.rank,
-                rc);
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Fence failed: %s\n", myproc.nspace, myproc.rank,
+                PMIx_Error_string(rc));
         goto done;
     }
     PMIX_INFO_FREE(info, 1);
 
+    /* get a list of our local peers */
+    if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, PMIX_LOCAL_PEERS, NULL, 0, &val))) {
+        fprintf(stderr, "Client ns %s rank %d: PMIx_Get local peers failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
+        goto done;
+    }
+    /* split the returned string to get the rank of each local peer */
+    peers = pmix_argv_split(val->data.string, ',');
+    PMIX_VALUE_RELEASE(val);
+    nlocal = pmix_argv_count(peers);
+    if (nprocs == nlocal) {
+        all_local = true;
+    } else {
+        all_local = false;
+        locals = (pmix_rank_t *) malloc(pmix_argv_count(peers) * sizeof(pmix_rank_t));
+        for (n = 0; NULL != peers[n]; n++) {
+            locals[n] = strtoul(peers[n], NULL, 10);
+        }
+    }
+    PMIX_ARGV_FREE(peers);
+
     /* check the returned data */
     for (n = 0; n < nprocs; n++) {
-        if (0 > asprintf(&tmp, "%s-%d-local", myproc.nspace, myproc.rank)) {
-            exit(1);
+        if (all_local) {
+            local = true;
+        } else {
+            local = false;
+            /* see if this proc is local to us */
+            for (k = 0; k < nlocal; k++) {
+                if (n == locals[k]) {
+                    local = true;
+                    break;
+                }
+            }
         }
-        if (PMIX_SUCCESS != (rc = PMIx_Get(&myproc, tmp, NULL, 0, &val))) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s failed: %d\n", myproc.nspace,
-                    myproc.rank, tmp, rc);
-            free(tmp);
-            goto done;
-        }
-        if (PMIX_UINT64 != val->type) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong type: %d\n",
-                    myproc.nspace, myproc.rank, tmp, val->type);
+        proc.rank = n;
+        if (local) {
+            if (0 > asprintf(&tmp, "%s-%d-local", myproc.nspace, proc.rank)) {
+                exit(1);
+            }
+            if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, tmp, NULL, 0, &val))) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s failed: %s\n", myproc.nspace,
+                        myproc.rank, tmp, PMIx_Error_string(rc));
+                free(tmp);
+                goto done;
+            }
+            if (PMIX_UINT64 != val->type) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong type: %d\n",
+                        myproc.nspace, myproc.rank, tmp, val->type);
+                PMIX_VALUE_RELEASE(val);
+                free(tmp);
+                goto done;
+            }
+            if (1234 != val->data.uint64) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong value: %d\n",
+                        myproc.nspace, myproc.rank, tmp, (int) val->data.uint64);
+                PMIX_VALUE_RELEASE(val);
+                free(tmp);
+                goto done;
+            }
+            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned correct\n", myproc.nspace,
+                    myproc.rank, tmp);
             PMIX_VALUE_RELEASE(val);
             free(tmp);
-            goto done;
-        }
-        if (1234 != val->data.uint64) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong value: %d\n",
-                    myproc.nspace, myproc.rank, tmp, (int) val->data.uint64);
+        } else {
+            if (0 > asprintf(&tmp, "%s-%d-remote", myproc.nspace, proc.rank)) {
+                exit(1);
+            }
+            if (PMIX_SUCCESS != (rc = PMIx_Get(&proc, tmp, NULL, 0, &val))) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s failed: %s\n", myproc.nspace,
+                        myproc.rank, tmp, PMIx_Error_string(rc));
+                free(tmp);
+                goto done;
+            }
+            if (PMIX_STRING != val->type) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong type: %d\n",
+                        myproc.nspace, myproc.rank, tmp, val->type);
+                PMIX_VALUE_RELEASE(val);
+                free(tmp);
+                goto done;
+            }
+            if (0 != strcmp(val->data.string, "1234")) {
+                fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong value: %s\n",
+                        myproc.nspace, myproc.rank, tmp, val->data.string);
+                PMIX_VALUE_RELEASE(val);
+                free(tmp);
+                goto done;
+            }
+            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned correct\n", myproc.nspace,
+                    myproc.rank, tmp);
             PMIX_VALUE_RELEASE(val);
             free(tmp);
-            goto done;
         }
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned correct\n", myproc.nspace,
-                myproc.rank, tmp);
-        PMIX_VALUE_RELEASE(val);
-        free(tmp);
-        if (0 > asprintf(&tmp, "%s-%d-remote", myproc.nspace, myproc.rank)) {
-            exit(1);
-        }
-        if (PMIX_SUCCESS != (rc = PMIx_Get(&myproc, tmp, NULL, 0, &val))) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s failed: %d\n", myproc.nspace,
-                    myproc.rank, tmp, rc);
-            free(tmp);
-            goto done;
-        }
-        if (PMIX_STRING != val->type) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong type: %d\n",
-                    myproc.nspace, myproc.rank, tmp, val->type);
-            PMIX_VALUE_RELEASE(val);
-            free(tmp);
-            goto done;
-        }
-        if (0 != strcmp(val->data.string, "1234")) {
-            fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned wrong value: %s\n",
-                    myproc.nspace, myproc.rank, tmp, val->data.string);
-            PMIX_VALUE_RELEASE(val);
-            free(tmp);
-            goto done;
-        }
-        fprintf(stderr, "Client ns %s rank %d: PMIx_Get %s returned correct\n", myproc.nspace,
-                myproc.rank, tmp);
-        PMIX_VALUE_RELEASE(val);
-        free(tmp);
     }
 
 done:
     /* finalize us */
     fprintf(stderr, "Client ns %s rank %d: Finalizing\n", myproc.nspace, myproc.rank);
     if (PMIX_SUCCESS != (rc = PMIx_Finalize(NULL, 0))) {
-        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %d\n", myproc.nspace,
-                myproc.rank, rc);
+        fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize failed: %s\n", myproc.nspace,
+                myproc.rank, PMIx_Error_string(rc));
     } else {
         fprintf(stderr, "Client ns %s rank %d:PMIx_Finalize successfully completed\n",
                 myproc.nspace, myproc.rank);
