@@ -8,7 +8,7 @@
  * Copyright (c) 2016-2018 Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -20,7 +20,7 @@
 
 #include "src/include/pmix_stdint.h"
 
-#include "include/pmix.h"
+#include "pmix.h"
 
 #include "src/include/pmix_globals.h"
 
@@ -50,20 +50,20 @@
 #include "src/mca/bfrops/bfrops.h"
 #include "src/mca/pcompress/base/base.h"
 #include "src/mca/ptl/base/base.h"
-#include "src/threads/threads.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/hash.h"
-#include "src/util/name_fns.h"
-#include "src/util/output.h"
+#include "src/threads/pmix_threads.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_hash.h"
+#include "src/util/pmix_name_fns.h"
+#include "src/util/pmix_output.h"
 #include "src/mca/gds/gds.h"
 #include "src/mca/ptl/base/base.h"
 
 #include "pmix_client_ops.h"
 
-static pmix_buffer_t* _pack_get(char *nspace, pmix_rank_t rank, char *key,
-                               const pmix_info_t info[], size_t ninfo,
-                               pmix_cmd_t cmd);
+static pmix_buffer_t* _pack_get(pmix_cb_t *cb,
+                                pmix_rank_t rank,
+                                pmix_cmd_t cmd);
 
 static void _getnbfn(int sd, short args, void *cbdata);
 
@@ -73,7 +73,7 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
 
 static void _value_cbfunc(pmix_status_t status, pmix_value_t *kv, void *cbdata);
 
-static pmix_status_t _getfn_fastpath(const pmix_proc_t *proc, const pmix_key_t key,
+static pmix_status_t _getfn_fastpath(const pmix_proc_t *proc, const char key[],
                                      const pmix_info_t info[], size_t ninfo,
                                      pmix_value_t **val);
 
@@ -81,7 +81,7 @@ static pmix_status_t process_values(pmix_value_t **v, pmix_cb_t *cb);
 
 
 PMIX_EXPORT pmix_status_t PMIx_Get(const pmix_proc_t *proc,
-                                   const pmix_key_t key,
+                                   const char key[],
                                    const pmix_info_t info[], size_t ninfo,
                                    pmix_value_t **val)
 {
@@ -133,22 +133,50 @@ static void gcbfn(int sd, short args, void *cbdata)
     PMIX_RELEASE(cb);
 }
 
+static void quicklook(int sd, short args, void *cbdata)
+{
+    pmix_cb_t *cb = (pmix_cb_t *) cbdata;
+    pmix_kval_t *kv;
+    pmix_status_t rc;
+    PMIX_HIDE_UNUSED_PARAMS(sd, args);
+
+    /* do the lookup */
+    PMIX_GDS_FETCH_KV(rc, pmix_globals.mypeer, cb);
+    cb->status = rc;
+    if(PMIX_SUCCESS == rc || PMIX_OPERATION_SUCCEEDED == rc) {
+        kv = (pmix_kval_t*)pmix_list_remove_first(&cb->kvs);
+        cb->value = kv->value;
+        kv->value = NULL;
+        PMIX_RELEASE(kv);
+    }
+    PMIX_POST_OBJECT(cb);
+    PMIX_WAKEUP_THREAD(&cb->lock);
+}
+
 PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
                                       const pmix_info_t info[], size_t ninfo,
                                       pmix_value_cbfunc_t cbfunc, void *cbdata)
 {
-    pmix_cb_t *cb;
+    pmix_cb_t *cb, cb2;
     pmix_status_t rc;
     size_t n, nfo;
-    bool wantinfo = false;
     char *hostname = NULL;
+    uint32_t sessionid = UINT32_MAX;
     uint32_t nodeid = UINT32_MAX;
     uint32_t appnum = UINT32_MAX;
-    uint32_t app;
     pmix_proc_t p;
     pmix_info_t *iptr;
     bool copy = false;
+    bool nodedirective = false;
+    bool nodeinfo = false;
+    bool appdirective = false;
+    bool appinfo = false;
+    bool sessiondirective = false;
+    bool sessioninfo = false;
+    bool refreshcache = false;
+    bool qval = false;
     pmix_value_t *ival = NULL;
+    pmix_info_t optional;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
@@ -252,156 +280,237 @@ PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
         if (NULL == key) {
             goto doget;
         }
-        /* see if they are asking about a node-level piece of info */
+        /* see if they are asking about a specific type of info */
         if (pmix_check_node_info(key)) {
+            nodeinfo = true;
+        } else if (pmix_check_app_info(key)) {
+            appinfo = true;
+        } else if (pmix_check_session_info(key)) {
+            sessioninfo = true;
+        }
+        for (n=0; n < ninfo; n++) {
+            if (PMIX_CHECK_KEY(&info[n], PMIX_JOB_INFO)) {
+                /* regardless of the default setting, they want us
+                 * to get it from the job realm */
+                nodeinfo = false;
+                appinfo = false;
+                sessioninfo = false;
+                /* have to let the loop continue in case there are
+                 * other relevant directives - e.g., refresh_cache */
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_NODE_INFO)) {
+                /* regardless of the default setting, they want us
+                 * to get it from the node realm */
+                nodedirective = true;
+                nodeinfo = true;
+                appinfo = false;
+                sessioninfo = false;
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_APP_INFO)) {
+                /* regardless of the default setting, they want us
+                 * to get it from the app realm */
+                appdirective = true;
+                appinfo = true;
+                nodeinfo = false;
+                sessioninfo = false;
+            } else if (PMIX_CHECK_KEY(info, PMIX_SESSION_INFO)) {
+                /* regardless of the default setting, they want us
+                 * to get it from the session realm */
+                sessiondirective = true;
+                sessioninfo = true;
+                nodeinfo = false;
+                appinfo = false;
+            } else if (PMIX_CHECK_KEY(info, PMIX_GET_REFRESH_CACHE)) {
+                refreshcache = true;
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_HOSTNAME)) {
+                hostname = info[n].value.data.string;
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_NODEID)) {
+                PMIX_VALUE_GET_NUMBER(rc, &info[n].value, nodeid, uint32_t);
+                if (PMIX_SUCCESS != rc) {
+                    PMIX_ERROR_LOG(rc);
+                    return rc;
+                }
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_APPNUM)) {
+                PMIX_VALUE_GET_NUMBER(rc, &info[n].value, appnum, uint32_t);
+                if (PMIX_SUCCESS != rc) {
+                    PMIX_ERROR_LOG(rc);
+                    return rc;
+                }
+            } else if (PMIX_CHECK_KEY(&info[n], PMIX_SESSION_ID)) {
+                PMIX_VALUE_GET_NUMBER(rc, &info[n].value, sessionid, uint32_t);
+                if (PMIX_SUCCESS != rc) {
+                    PMIX_ERROR_LOG(rc);
+                    return rc;
+                }
+            }
+        }
+        /* if they want us to refresh our cache, then we have
+         * to go ask the server for it */
+        if (refreshcache) {
+            goto doget;
+        }
+        PMIX_INFO_LOAD(&optional, PMIX_OPTIONAL, NULL, PMIX_BOOL);
 
+        if (nodeinfo) {
             pmix_output_verbose(2, pmix_client_globals.get_output,
                                 "pmix: get_nb value requesting node-level info for proc %s key %s",
                                 PMIX_NAME_PRINT(&p), (NULL == key) ? "NULL" : key);
-
-            /* the key is node-related - see if the target node is in the
-             * info array and if they tagged the request accordingly */
-            if (NULL != info) {
-                for (n=0; n < ninfo; n++) {
-                    if (PMIX_CHECK_KEY(&info[n], PMIX_NODE_INFO)) {
-                        wantinfo = true;
-                    } else if (PMIX_CHECK_KEY(&info[n], PMIX_HOSTNAME)) {
-                        hostname = info[n].value.data.string;
-                    } else if (PMIX_CHECK_KEY(&info[n], PMIX_NODEID)) {
-                        PMIX_VALUE_GET_NUMBER(rc, &info[n].value, nodeid, uint32_t);
-                        if (PMIX_SUCCESS != rc) {
-                            PMIX_ERROR_LOG(rc);
-                            return rc;
+            if (NULL == hostname && UINT32_MAX == nodeid) {
+                /* if they didn't specify the target node, then see if they
+                 * specified a proc */
+                if (PMIX_RANK_IS_VALID(p.rank)) {
+                    /* lookup the node where that proc is running - if all we
+                     * have is the hash component, then we have to threadshift
+                     * to make that request */
+                    rc = _getfn_fastpath(&p, PMIX_HOSTNAME, &optional, 1, &ival);
+                    if (PMIX_ERR_NOT_SUPPORTED == rc) {
+                        /* all we have is hash */
+                        PMIX_CONSTRUCT(&cb2, pmix_cb_t);
+                        cb2.proc = &p;
+                        cb2.key = PMIX_HOSTNAME;
+                        cb2.info = &optional;
+                        cb2.ninfo = 1;
+                        PMIX_THREADSHIFT(&cb2, quicklook);
+                        PMIX_WAIT_THREAD(&cb2.lock);
+                        rc = cb2.status;
+                        if (NULL != cb2.value) {
+                            ival = cb2.value;
+                            cb2.value = NULL;
                         }
+                        PMIX_DESTRUCT(&cb2);
                     }
+                    if (PMIX_SUCCESS == rc) {
+                        hostname = ival->data.string;
+                        /* if they were asking for the hostname, then we are done */
+                        if (0 == strcmp(key, PMIX_HOSTNAME)) {
+                            cb = PMIX_NEW(pmix_cb_t);
+                            cb->status = PMIX_SUCCESS;
+                            cb->value = ival;
+                            cb->cbfunc.valuefn = cbfunc;
+                            cb->cbdata = cbdata;
+                            PMIX_THREADSHIFT(cb, gcbfn);
+                            return PMIX_SUCCESS;
+                        }
+                        if (0 == strcmp(hostname, pmix_globals.hostname)) {
+                            /* it is us - let dstore handle it */
+                            PMIX_VALUE_RELEASE(ival);
+                            goto fastpath;
+                        }
+                        /* mark this as a node info request */
+                        if (nodedirective) {
+                            /* just need to add the hostname */
+                            nfo = ninfo + 2;
+                            PMIX_INFO_CREATE(iptr, nfo);
+                            for (n=0; n < ninfo; n++) {
+                                PMIX_INFO_XFER(&iptr[n], &info[n]);
+                            }
+                            PMIX_INFO_LOAD(&iptr[ninfo], PMIX_HOSTNAME, hostname, PMIX_STRING);
+                            PMIX_INFO_LOAD(&iptr[ninfo+1], PMIX_OPTIONAL, NULL, PMIX_BOOL);
+                            copy = true;
+                        } else {
+                            /* need to add directive and hostname */
+                            nfo = ninfo + 3;
+                            PMIX_INFO_CREATE(iptr, nfo);
+                            for (n=0; n < ninfo; n++) {
+                                PMIX_INFO_XFER(&iptr[n], &info[n]);
+                            }
+                            PMIX_INFO_LOAD(&iptr[ninfo], PMIX_NODE_INFO, NULL, PMIX_BOOL);
+                            PMIX_INFO_LOAD(&iptr[ninfo + 1], PMIX_HOSTNAME, hostname, PMIX_STRING);
+                            PMIX_INFO_LOAD(&iptr[ninfo+2], PMIX_OPTIONAL, NULL, PMIX_BOOL);
+                            copy = true;
+                        }
+                        PMIX_VALUE_RELEASE(ival);
+                        /* proc is on identified host - let hash handle it */
+                        p.rank = PMIX_RANK_UNDEF;
+                        goto doget;
+                    }
+                    /* could not find hostname, so we cannot do anything */
+                    return PMIX_ERR_NOT_FOUND;
                 }
+                /* nothing was specified, so assume our node and let dstore handle it */
+                if (PMIX_RANK_UNDEF == p.rank) {
+                    p.rank = PMIX_RANK_WILDCARD;
+                }
+                goto fastpath;
             }
-           /* see if they told us to get node info */
-            if (!wantinfo) {
-                pmix_output_verbose(2, pmix_client_globals.get_output,
-                                    "pmix: get_nb value did not specify node info for proc %s key %s",
-                                    PMIX_NAME_PRINT(&p), (NULL == key) ? "NULL" : key);
-                /* guess not - better do it */
-                nfo = ninfo + 1;
+            if (NULL != hostname && 0 == strcmp(hostname, pmix_globals.hostname)) {
+                /* the node is us - let dstore handle it */
+                if (PMIX_RANK_UNDEF == p.rank) {
+                    p.rank = PMIX_RANK_WILDCARD;
+                }
+                goto fastpath;
+            }
+            if (UINT32_MAX != nodeid && nodeid == pmix_globals.nodeid) {
+                /* the node is us - let dstore handle it */
+                if (PMIX_RANK_UNDEF == p.rank) {
+                    p.rank = PMIX_RANK_WILDCARD;
+                }
+                goto fastpath;
+            }
+            /* the node is not us - did they tell us the node? */
+            if (NULL == hostname && UINT32_MAX == nodeid) {
+                /* we have nothing and cannot find the host for
+                 * an invalid rank */
+                return PMIX_ERR_NOT_FOUND;
+            }
+            if (!nodedirective) {
+                /* need to add directive - hostname and/or nodeid are already present */
+                nfo = ninfo + 2;
                 PMIX_INFO_CREATE(iptr, nfo);
                 for (n=0; n < ninfo; n++) {
                     PMIX_INFO_XFER(&iptr[n], &info[n]);
                 }
                 PMIX_INFO_LOAD(&iptr[ninfo], PMIX_NODE_INFO, NULL, PMIX_BOOL);
+                PMIX_INFO_LOAD(&iptr[ninfo+1], PMIX_OPTIONAL, NULL, PMIX_BOOL);
                 copy = true;
             }
-            if (NULL != hostname || UINT32_MAX != nodeid) {
-                /* if they specified the target node and it is us, then dstore can
-                 * resolve it and we need the rank to be wildcard */
-                if ((NULL != hostname && 0 == strcmp(hostname, pmix_globals.hostname)) ||
-                    nodeid == pmix_globals.nodeid) {
-                    if (PMIX_RANK_UNDEF == p.rank) {
-                        p.rank = PMIX_RANK_WILDCARD;
-                    }
-                    goto fastpath;
-                }
-                /* ask the hash to resolve it */
-                if (PMIX_RANK_UNDEF == p.rank) {
-                    p.rank = PMIX_RANK_WILDCARD;
-                }
-                goto doget;
-            }
-            /* if they didn't specify a node, then assume it is us and let the dstore handle it */
-            goto fastpath;
+            p.rank = PMIX_RANK_UNDEF;  // ensure invalid rank
+            goto doget;
         }
 
-        /* see if they are asking about an app-level piece of info */
-        wantinfo = false;
-        if (pmix_check_app_info(key)) {
-            /* the key is app-related - see if the target appnum is in the
-             * info array and if they tagged the request accordingly */
-            if (NULL != info) {
-                for (n=0; n < ninfo; n++) {
-                    if (PMIX_CHECK_KEY(&info[n], PMIX_APP_INFO)) {
-                        wantinfo = true;
-                    } else if (PMIX_CHECK_KEY(&info[n], PMIX_APPNUM) &&
-                               0 != info[n].value.data.uint32) {
-                        PMIX_VALUE_GET_NUMBER(rc, &info[n].value, appnum, uint32_t);
-                        if (PMIX_SUCCESS != rc) {
-                            PMIX_ERROR_LOG(rc);
-                            return rc;
-                        }
-                    }
-                }
-            }
-            if (PMIX_PEER_IS_EARLIER(pmix_client_globals.myserver, 3, 2, 100)) {
-               /* see if they told us to get app info */
-                if (!wantinfo) {
-                    /* guess not - better do it */
-                    nfo = ninfo + 1;
-                    PMIX_INFO_CREATE(iptr, nfo);
-                    for (n=0; n < ninfo; n++) {
-                        PMIX_INFO_XFER(&iptr[n], &info[n]);
-                    }
-                    PMIX_INFO_LOAD(&iptr[ninfo], PMIX_APP_INFO, NULL, PMIX_BOOL);
-                    copy = true;
-                    goto doget;
-                }
-                goto doget;
-            }
-            if (wantinfo && UINT32_MAX != appnum) {
-                /* asked for app-level info and provided an appnum - if it
-                 * isn't our appnum, then we need to redirect */
-                rc = _getfn_fastpath(&pmix_globals.myid, PMIX_APPNUM, NULL, 0, &ival);
-                if (PMIX_SUCCESS == rc) {
-                    PMIX_VALUE_GET_NUMBER(rc, ival, app, uint32_t);
-                    if (PMIX_SUCCESS != rc) {
-                        PMIX_ERROR_LOG(rc);
-                        return rc;
-                    }
-                    PMIX_VALUE_RELEASE(ival);
-                    if (app == appnum) {
-                        goto fastpath;
-                    }
-                }
-                goto doget;
-            } else if (wantinfo) {
-                /* missing the appnum - assume it is ours */
-                goto fastpath;
-            } else if (UINT32_MAX != appnum) {
-                /* they did not provide the "app-info" attribute but did specify
-                 * the appnum - if the ID is other than us, then we just need to
-                 * flag it as "app-info" and mark it for the undefined rank so
-                 * the GDS will know where to look */
-                rc = _getfn_fastpath(&pmix_globals.myid, PMIX_APPNUM, NULL, 0, &ival);
-                if (PMIX_SUCCESS == rc) {
-                    PMIX_VALUE_GET_NUMBER(rc, ival, app, uint32_t);
-                    if (PMIX_SUCCESS != rc) {
-                        PMIX_ERROR_LOG(rc);
-                        return rc;
-                    }
-                    PMIX_VALUE_RELEASE(ival);
-                    if (app == appnum) {
-                        goto fastpath;
-                    }
-                }
-                nfo = ninfo + 1;
+        if (appinfo) {
+           /* have to get this from the hash */
+            if (!appdirective) {
+                /* didn't provide a directive - add it */
+                nfo = ninfo + 2;
                 PMIX_INFO_CREATE(iptr, nfo);
                 for (n=0; n < ninfo; n++) {
                     PMIX_INFO_XFER(&iptr[n], &info[n]);
                 }
                 PMIX_INFO_LOAD(&iptr[ninfo], PMIX_APP_INFO, NULL, PMIX_BOOL);
+                PMIX_INFO_LOAD(&iptr[ninfo+1], PMIX_OPTIONAL, NULL, PMIX_BOOL);
                 copy = true;
-                goto doget;
-            } else {
-                /* missing both - all we can do is assume they want our info */
-                goto fastpath;
             }
+            if (UINT32_MAX == appnum) {
+              /* missing the appnum - assume it is ours */
+                if (PMIX_RANK_UNDEF == p.rank) {
+                    p.rank = PMIX_RANK_WILDCARD;
+                }
+            }
+            goto doget;
         }
 
-        /* see if they are requesting session info or requesting cache refresh */
-        for (n=0; n < ninfo; n++) {
-            if (PMIX_CHECK_KEY(info, PMIX_SESSION_INFO) ||
-                PMIX_CHECK_KEY(info, PMIX_GET_REFRESH_CACHE)) {
-                goto doget;
+        if (sessioninfo) {
+            /* have to get this from the hash */
+            if (!sessiondirective) {
+                /* didn't provide a directive - add it */
+                nfo = ninfo + 2;
+                PMIX_INFO_CREATE(iptr, nfo);
+                for (n=0; n < ninfo; n++) {
+                    PMIX_INFO_XFER(&iptr[n], &info[n]);
+                }
+                PMIX_INFO_LOAD(&iptr[ninfo], PMIX_SESSION_INFO, NULL, PMIX_BOOL);
+                PMIX_INFO_LOAD(&iptr[ninfo+1], PMIX_OPTIONAL, NULL, PMIX_BOOL);
+                copy = true;
             }
+            if (UINT32_MAX == sessionid) {
+                /* missing the session ID - assume it is ours */
+                if (PMIX_RANK_UNDEF == p.rank) {
+                    p.rank = PMIX_RANK_WILDCARD;
+                }
+            }
+            goto doget;
         }
     }
+
     /* don't consider the fastpath option
      * for undefined rank or NULL keys */
     if (PMIX_RANK_UNDEF == p.rank || NULL == key) {
@@ -409,6 +518,15 @@ PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
     }
 
   fastpath:
+    /* if the info contains qualifiers, then pass it to the
+     * gds/hash component as dstor doesn't know how to handle it */
+    for (n=0; n < nfo; n++) {
+        if (PMIX_INFO_IS_QUALIFIER(&iptr[n])) {
+            qval = true;
+            goto doget;
+        }
+    }
+
     /* try to get data directly, without threadshift */
     pmix_output_verbose(2, pmix_client_globals.get_output,
                         "pmix: get_nb value trying fastpath for proc %s key %s",
@@ -422,6 +540,9 @@ PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
         cb->cbfunc.valuefn = cbfunc;
         cb->cbdata = cbdata;
         PMIX_THREADSHIFT(cb, gcbfn);
+        if (copy) {
+            PMIX_INFO_FREE(iptr, nfo);
+        }
         return PMIX_SUCCESS;
     }
 
@@ -437,6 +558,9 @@ PMIX_EXPORT pmix_status_t PMIx_Get_nb(const pmix_proc_t *proc, const char key[],
     cb->info = iptr;
     cb->ninfo = nfo;
     cb->infocopy = copy;
+    cb->lg = (pmix_get_logic_t*)pmix_malloc(sizeof(pmix_get_logic_t));
+    memset(cb->lg, 0, sizeof(pmix_get_logic_t));
+    cb->lg->qualified_value = qval;
     cb->cbfunc.valuefn = cbfunc;
     cb->cbdata = cbdata;
     PMIX_THREADSHIFT(cb, _getnbfn);
@@ -457,12 +581,15 @@ static void _value_cbfunc(pmix_status_t status, pmix_value_t *kv, void *cbdata)
     PMIX_WAKEUP_THREAD(&cb->lock);
 }
 
-static pmix_buffer_t* _pack_get(char *nspace, pmix_rank_t rank, char *key,
-                               const pmix_info_t info[], size_t ninfo,
-                               pmix_cmd_t cmd)
+static pmix_buffer_t* _pack_get(pmix_cb_t *cb,
+                                pmix_rank_t rank,
+                                pmix_cmd_t cmd)
 {
     pmix_buffer_t *msg;
     pmix_status_t rc;
+    pmix_info_t *immediate;
+    size_t n, nimm;
+    char *nspace = cb->proc->nspace;
 
     /* nope - see if we can get it */
     msg = PMIX_NEW(pmix_buffer_t);
@@ -491,26 +618,37 @@ static pmix_buffer_t* _pack_get(char *nspace, pmix_rank_t rank, char *key,
         return NULL;
     }
     /* pack the number of info structs */
+    if (cb->lg->add_immediate) {
+        nimm = cb->ninfo + 1;
+        PMIX_INFO_CREATE(immediate, nimm);
+        for (n=0; n < cb->ninfo; n++) {
+            PMIX_INFO_XFER(&immediate[n], &cb->info[n]);
+        }
+        PMIX_INFO_LOAD(&immediate[n], PMIX_IMMEDIATE, NULL, PMIX_BOOL);
+        cb->info = immediate;
+        cb->ninfo = nimm;
+        cb->infocopy = true;
+    }
     PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                     msg, &ninfo, 1, PMIX_SIZE);
+                     msg, &cb->ninfo, 1, PMIX_SIZE);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
         PMIX_RELEASE(msg);
         return NULL;
     }
-    if (0 < ninfo) {
+    if (0 < cb->ninfo) {
         PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, info, ninfo, PMIX_INFO);
+                         msg, cb->info, cb->ninfo, PMIX_INFO);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
             return NULL;
         }
     }
-    if (NULL != key) {
+    if (NULL != cb->key) {
         /* pack the key */
         PMIX_BFROPS_PACK(rc, pmix_client_globals.myserver,
-                         msg, &key, 1, PMIX_STRING);
+                         msg, &cb->key, 1, PMIX_STRING);
         if (PMIX_SUCCESS != rc) {
             PMIX_ERROR_LOG(rc);
             PMIX_RELEASE(msg);
@@ -531,7 +669,7 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
 {
     pmix_cb_t *cb = (pmix_cb_t*)cbdata;
     pmix_cb_t *cb2;
-    pmix_status_t rc, ret;
+    pmix_status_t rc, ret = PMIX_ERR_NOT_FOUND;
     pmix_value_t *val = NULL;
     int32_t cnt;
     pmix_proc_t proc;
@@ -541,7 +679,8 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
     PMIX_ACQUIRE_OBJECT(cb);
     PMIX_HIDE_UNUSED_PARAMS(pr, hdr);
 
-    pmix_output_verbose(2, pmix_client_globals.get_output, "pmix: get_nb callback recvd");
+    pmix_output_verbose(2, pmix_client_globals.get_output,
+                        "pmix: get_nb callback recvd");
 
     if (NULL == cb) {
         /* nothing we can do */
@@ -577,7 +716,8 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
 
     if (PMIX_SUCCESS != ret) {
         pmix_output_verbose(2, pmix_client_globals.get_output,
-                            "pmix: get_nb server returned %s", PMIx_Error_string(ret));
+                            "pmix: get_nb server returned %s for key %s from proc %s:%d",
+                            PMIx_Error_string(ret), cb->key, cb->pname.nspace, cb->pname.rank);
         goto done;
     }
     PMIX_GDS_ACCEPT_KVS_RESP(rc, pmix_globals.mypeer, buf);
@@ -590,9 +730,14 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
     pmix_output_verbose(2, pmix_client_globals.get_output,
                         "pmix: get_nb looking for requested key");
     PMIX_LIST_FOREACH_SAFE(cb, cb2, &pmix_client_globals.pending_requests, pmix_cb_t) {
-        if (0 == strncmp(proc.nspace, cb->pname.nspace, PMIX_MAX_NSLEN) &&
-            cb->pname.rank == proc.rank) {
-           /* we have the data for this proc - see if we can find the key */
+        if (PMIX_CHECK_NSPACE(proc.nspace, cb->pname.nspace) && cb->pname.rank == proc.rank) {
+            pmix_list_remove_item(&pmix_client_globals.pending_requests, &cb->super);
+            if (PMIX_SUCCESS != ret) {
+                cb->cbfunc.valuefn(ret, NULL, cb->cbdata);
+                PMIX_RELEASE(cb);
+                continue;
+            }
+            /* we have the data for this proc - see if we can find the key */
             cb->proc = &proc;
             cb->scope = PMIX_SCOPE_UNDEF;
             /* fetch the data from server peer module - since it is passing
@@ -605,9 +750,23 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
                 }
             }
             pmix_output_verbose(2, pmix_client_globals.get_output,
-                                "pmix: get_nb searching for key %s for rank %s", cb->key, PMIX_RANK_PRINT(proc.rank));
+                                "pmix: get_nb searching for key %s for proc %s",
+                                cb->key, PMIX_NAME_PRINT(&proc));
             PMIX_GDS_FETCH_KV(rc, pmix_globals.mypeer, cb);
-            if (PMIX_SUCCESS == rc) {
+            if (PMIX_SUCCESS != rc && PMIX_OPERATION_SUCCEEDED != rc) {
+               /* if we are both using the "hash" component, then the server's peer
+                * will simply be pointing at the same hash tables as my peer - no
+                * no point in checking there again */
+                if (!cb->lg->qualified_value &&
+                    !PMIX_GDS_CHECK_PEER_COMPONENT(pmix_globals.mypeer,
+                                                   pmix_client_globals.myserver)) {
+                    pmix_output_verbose(2, pmix_client_globals.get_output,
+                                        "pmix: get_nb searching for key %s for proc %s, - %s",
+                                        cb->key, PMIX_NAME_PRINT(&proc), pmix_client_globals.myserver->nptr->compat.gds->name);
+                    PMIX_GDS_FETCH_KV(rc, pmix_client_globals.myserver, cb);
+                }
+            }
+            if (PMIX_SUCCESS == rc || PMIX_OPERATION_SUCCEEDED == rc) {
                 if (1 != pmix_list_get_size(&cb->kvs)) {
                     rc = PMIX_ERR_INVALID_VAL;
                     val = NULL;
@@ -617,9 +776,9 @@ static void _getnb_cbfunc(struct pmix_peer_t *pr,
                     kv->value = NULL; // protect the value
                     PMIX_RELEASE(kv);
                 }
+                rc = PMIX_SUCCESS;
             }
             cb->cbfunc.valuefn(rc, val, cb->cbdata);
-            pmix_list_remove_item(&pmix_client_globals.pending_requests, &cb->super);
             PMIX_RELEASE(cb);
         }
     }
@@ -664,7 +823,7 @@ static pmix_status_t process_values(pmix_value_t **v, pmix_cb_t *cb)
     n=0;
     PMIX_LIST_FOREACH(kv, kvs, pmix_kval_t) {
         pmix_strncpy(info[n].key, kv->key, PMIX_MAX_KEYLEN);
-        pmix_value_xfer(&info[n].value, kv->value);
+        PMIx_Value_xfer(&info[n].value, kv->value);
         ++n;
     }
     val->data.darray->size = ninfo;
@@ -673,7 +832,7 @@ static pmix_status_t process_values(pmix_value_t **v, pmix_cb_t *cb)
     return PMIX_SUCCESS;
 }
 
-static pmix_status_t _getfn_fastpath(const pmix_proc_t *proc, const pmix_key_t key,
+static pmix_status_t _getfn_fastpath(const pmix_proc_t *proc, const char key[],
                                      const pmix_info_t info[], size_t ninfo,
                                      pmix_value_t **val)
 {
@@ -723,6 +882,7 @@ static void _getnbfn(int fd, short flags, void *cbdata)
     size_t n;
     pmix_proc_t proc;
     bool optional = false;
+    bool immediate = false;
     bool internal_only = false;
 
     /* cb was passed to us from another thread - acquire it */
@@ -743,6 +903,8 @@ static void _getnbfn(int fd, short flags, void *cbdata)
         for (n=0; n < cb->ninfo; n++) {
             if (PMIX_CHECK_KEY(&cb->info[n], PMIX_OPTIONAL)) {
                 optional = PMIX_INFO_TRUE(&cb->info[n]);
+            } else if (PMIX_CHECK_KEY(&cb->info[n], PMIX_IMMEDIATE)) {
+                immediate = PMIX_INFO_TRUE(&cb->info[n]);
             } else if (PMIX_CHECK_KEY(&cb->info[n], PMIX_DATA_SCOPE)) {
                 cb->scope = cb->info[n].value.data.scope;
             } else if (PMIX_CHECK_KEY(&cb->info[n], PMIX_NODE_INFO) ||
@@ -765,13 +927,19 @@ static void _getnbfn(int fd, short flags, void *cbdata)
                             "pmix:client data found in internal storage");
         rc = process_values(&val, cb);
         goto respond;
+    } else if (cb->lg->qualified_value) {
+        if (!immediate) {
+            cb->lg->add_immediate = true;
+        }
+        goto request;
     }
+
     pmix_output_verbose(5, pmix_client_globals.get_output,
                         "pmix:client data NOT found in internal storage");
 
     /* if the key is NULL or starts with "pmix", then they are looking
      * for data that was provided by the server at startup */
-    if (!internal_only && (NULL == cb->key || 0 == strncmp(cb->key, "pmix", 4))) {
+    if (!internal_only && (NULL == cb->key || PMIX_CHECK_RESERVED_KEY(cb->key))) {
         pmix_output_verbose(2, pmix_client_globals.get_output,
                             "pmix: get_nb looking for job info");
         cb->proc = &proc;
@@ -780,7 +948,7 @@ static void _getnbfn(int fd, short flags, void *cbdata)
         cb->copy = true;
         /* if the peer and server GDS component are the same, then no
          * point in trying it again */
-        if (0 != strcmp(pmix_globals.mypeer->nptr->compat.gds->name, pmix_client_globals.myserver->nptr->compat.gds->name)) {
+        if (!PMIX_GDS_CHECK_COMPONENT(pmix_client_globals.myserver, "hash")) {
             PMIX_GDS_FETCH_KV(rc, pmix_client_globals.myserver, cb);
         } else {
             rc = PMIX_ERR_NOT_FOUND;
@@ -788,7 +956,8 @@ static void _getnbfn(int fd, short flags, void *cbdata)
         if (PMIX_SUCCESS != rc) {
             pmix_output_verbose(5, pmix_client_globals.get_output,
                                 "pmix:client job-level data NOT found");
-            if (!PMIX_CHECK_NSPACE(cb->pname.nspace, pmix_globals.myid.nspace)) {
+            if (PMIX_PEER_IS_EARLIER(pmix_client_globals.myserver, 3, 1, 100) ||
+                !PMIX_CHECK_NSPACE(cb->pname.nspace, pmix_globals.myid.nspace)) {
                 /* we are asking about the job-level info from another
                  * namespace. It seems that we don't have it - go and
                  * ask server and indicate we only need job-level info
@@ -797,23 +966,18 @@ static void _getnbfn(int fd, short flags, void *cbdata)
                 proc.rank = PMIX_RANK_WILDCARD;
                 goto request;
             } else if (NULL != cb->key) {
-                /* => cb->key starts with pmix
-                 * if the server is pre-v3.2, then we have to go up and ask
-                 * for the info */
-                if (PMIX_PEER_IS_EARLIER(pmix_client_globals.myserver, 3, 1, 100)) {
-                    pmix_output_verbose(5, pmix_client_globals.get_output,
-                                        "pmix:client old server - fetching data");
-                    proc.rank = PMIX_RANK_WILDCARD;
-                    goto request;
-                } else if (PMIX_CHECK_KEY(cb, PMIX_GROUP_CONTEXT_ID)) {
-                    goto request;
-                }
-                /* we should have had this info, so respond with the error - if
-                 * they want us to check with the server, they should ask us to
-                 * refresh the cache */
+                /* this is a reserved key - we should have had this info, but
+                 * it is possible that some system don't provide it, thereby
+                 * causing the app to manually distribute it. We will therefore
+                 * request it from the server, but do so under the "immediate"
+                 * use-case, adding that flag if they didn't already include it
+                 */
                 pmix_output_verbose(5, pmix_client_globals.get_output,
-                                    "pmix:client returning NOT FOUND error");
-                goto respond;
+                                    "pmix:client reserved key not locally found");
+                if (!immediate) {
+                    cb->lg->add_immediate = true;
+                }
+                goto request;
             } else {
                 pmix_output_verbose(5, pmix_client_globals.get_output,
                                     "pmix:client NULL KEY - returning error");
@@ -833,7 +997,8 @@ static void _getnbfn(int fd, short flags, void *cbdata)
     } else {
         /* if the peer and server GDS component are the same, then no
          * point in trying it again */
-        if (0 == strcmp(pmix_globals.mypeer->nptr->compat.gds->name, pmix_client_globals.myserver->nptr->compat.gds->name)) {
+        if (PMIX_GDS_CHECK_PEER_COMPONENT(pmix_client_globals.myserver,
+                                          pmix_globals.mypeer)) {
             val = NULL;
             goto request;
         }
@@ -900,7 +1065,7 @@ static void _getnbfn(int fd, short flags, void *cbdata)
     }
 
     /* we don't have a pending request, so let's create one */
-    msg = _pack_get(cb->proc->nspace, proc.rank, cb->key, cb->info, cb->ninfo, PMIX_GETNB_CMD);
+    msg = _pack_get(cb, proc.rank, PMIX_GETNB_CMD);
     if (NULL == msg) {
         rc = PMIX_ERROR;
         PMIX_ERROR_LOG(rc);
