@@ -12,7 +12,7 @@
  *                         All rights reserved.
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2020      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -24,12 +24,13 @@
 #define PMIX_EVENT_H
 
 #include "src/include/pmix_config.h"
-#include "src/include/types.h"
+#include "src/include/pmix_types.h"
 #include <event.h>
 
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 #include "src/class/pmix_list.h"
-#include "src/util/output.h"
+#include "src/mca/bfrops/bfrops_types.h"
+#include "src/util/pmix_output.h"
 
 BEGIN_C_DECLS
 
@@ -62,6 +63,7 @@ typedef struct {
     char *name;
     size_t index;
     uint8_t precedence;
+    bool oneshot;
     char *locator;
     pmix_proc_t source; // who generated this event
     /* When registering for events, callers can specify
@@ -110,6 +112,18 @@ typedef struct {
 } pmix_events_t;
 PMIX_CLASS_DECLARATION(pmix_events_t);
 
+#define PMIX_EVENTS_STATIC_INIT                     \
+{                                                   \
+    .super = PMIX_OBJ_STATIC_INIT(pmix_object_t),   \
+    .nhdlrs = 0,                                    \
+    .first = NULL,                                  \
+    .last = NULL,                                   \
+    .actives = PMIX_LIST_STATIC_INIT,               \
+    .single_events = PMIX_LIST_STATIC_INIT,         \
+    .multi_events = PMIX_LIST_STATIC_INIT,          \
+    .default_events = PMIX_LIST_STATIC_INIT         \
+}
+
 /* define an object for chaining event notifications thru
  * the local state machine. Each registered event handler
  * that asked to be notified for a given code is given a
@@ -159,7 +173,7 @@ PMIX_CLASS_DECLARATION(pmix_event_chain_t);
 PMIX_EXPORT pmix_status_t pmix_prep_event_chain(pmix_event_chain_t *chain, const pmix_info_t *info,
                                                 size_t ninfo, bool xfer);
 
-/* invoke the error handler that is registered against the given
+/* invoke the pmix_error.handler that is registered against the given
  * status, passing it the provided info on the procs that were
  * affected, plus any additional info provided by the server */
 PMIX_EXPORT void pmix_invoke_local_event_hdlr(pmix_event_chain_t *chain);
@@ -169,12 +183,19 @@ PMIX_EXPORT bool pmix_notify_check_range(pmix_range_trkr_t *rng, const pmix_proc
 PMIX_EXPORT bool pmix_notify_check_affected(pmix_proc_t *interested, size_t ninterested,
                                             pmix_proc_t *affected, size_t naffected);
 
+PMIX_EXPORT pmix_status_t pmix_deregister_event_hdlr(size_t event_hdlr_ref,
+                                                     pmix_buffer_t *msg);
+
 /* invoke the server event notification handler */
 PMIX_EXPORT pmix_status_t pmix_server_notify_client_of_event(pmix_status_t status,
                                                              const pmix_proc_t *source,
                                                              pmix_data_range_t range,
                                                              const pmix_info_t info[], size_t ninfo,
                                                              pmix_op_cbfunc_t cbfunc, void *cbdata);
+PMIX_EXPORT pmix_status_t pmix_notify_server_of_event(pmix_status_t status, const pmix_proc_t *source,
+                                                      pmix_data_range_t range, const pmix_info_t info[],
+                                                      size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata,
+                                                      bool dolocal);
 
 PMIX_EXPORT void pmix_event_timeout_cb(int fd, short flags, void *arg);
 
