@@ -5,7 +5,7 @@
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2017      IBM Corporation. All rights reserved.
  *
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -14,23 +14,20 @@
  */
 #include "src/include/pmix_config.h"
 
-#include "include/pmix.h"
-#include "include/pmix_common.h"
+#include "pmix.h"
+#include "pmix_common.h"
 #include "include/pmix_server.h"
 
-#include "src/threads/threads.h"
-#include "src/util/error.h"
-#include "src/util/name_fns.h"
-#include "src/util/output.h"
+#include "src/threads/pmix_threads.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_name_fns.h"
+#include "src/util/pmix_output.h"
 
 #include "src/client/pmix_client_ops.h"
 #include "src/include/pmix_globals.h"
 #include "src/mca/bfrops/bfrops.h"
 #include "src/server/pmix_server_ops.h"
 
-static pmix_status_t notify_server_of_event(pmix_status_t status, const pmix_proc_t *source,
-                                            pmix_data_range_t range, const pmix_info_t info[],
-                                            size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata);
 static void progress_local_event_hdlr(pmix_status_t status, pmix_info_t *results, size_t nresults,
                                       pmix_op_cbfunc_t cbfunc, void *thiscbdata,
                                       void *notification_cbdata);
@@ -51,7 +48,8 @@ PMIX_EXPORT pmix_status_t PMIx_Notify_event(pmix_status_t status, const pmix_pro
         return PMIX_ERR_INIT;
     }
 
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) || PMIX_PEER_IS_TOOL(pmix_globals.mypeer)) {
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) ||
+        PMIX_PEER_IS_TOOL(pmix_globals.mypeer)) {
         PMIX_RELEASE_THREAD(&pmix_global_lock);
 
         pmix_output_verbose(2, pmix_server_globals.event_output,
@@ -82,14 +80,16 @@ PMIX_EXPORT pmix_status_t PMIx_Notify_event(pmix_status_t status, const pmix_pro
                         (NULL == source) ? pmix_globals.myid.nspace : source->nspace,
                         (NULL == source) ? pmix_globals.myid.rank : source->rank, status);
 
-    rc = notify_server_of_event(status, source, range, info, ninfo, cbfunc, cbdata);
+    rc = pmix_notify_server_of_event(status, source, range, info, ninfo, cbfunc, cbdata, true);
     if (PMIX_SUCCESS != rc) {
         PMIX_ERROR_LOG(rc);
     }
     return rc;
 }
 
-static void notify_event_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmix_buffer_t *buf,
+static void notify_event_cbfunc(struct pmix_peer_t *pr,
+                                pmix_ptl_hdr_t *hdr,
+                                pmix_buffer_t *buf,
                                 void *cbdata)
 {
     (void) hdr;
@@ -97,7 +97,7 @@ static void notify_event_cbfunc(struct pmix_peer_t *pr, pmix_ptl_hdr_t *hdr, pmi
     int32_t cnt = 1;
     pmix_cb_t *cb = (pmix_cb_t *) cbdata;
 
-    if (0 < hdr->nbytes) {
+    if (0 < buf->bytes_used) {
         /* unpack the status */
         PMIX_BFROPS_UNPACK(rc, pr, buf, &ret, &cnt, PMIX_STATUS);
         if (PMIX_SUCCESS != rc) {
@@ -157,15 +157,16 @@ pmix_status_t pmix_notify_event_cache(pmix_notify_caddy_t *cd)
 }
 
 /* as a client, we pass the notification to our server */
-static pmix_status_t notify_server_of_event(pmix_status_t status, const pmix_proc_t *source,
-                                            pmix_data_range_t range, const pmix_info_t info[],
-                                            size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata)
+pmix_status_t pmix_notify_server_of_event(pmix_status_t status, const pmix_proc_t *source,
+                                          pmix_data_range_t range, const pmix_info_t info[],
+                                          size_t ninfo, pmix_op_cbfunc_t cbfunc, void *cbdata,
+                                          bool dolocal)
 {
     pmix_status_t rc;
     pmix_buffer_t *msg = NULL;
     pmix_cmd_t cmd = PMIX_NOTIFY_CMD;
     pmix_cb_t *cb;
-    pmix_event_chain_t *chain;
+    pmix_event_chain_t *chain = NULL;
     size_t n;
     pmix_notify_caddy_t *cd;
 
@@ -217,64 +218,68 @@ static pmix_status_t notify_server_of_event(pmix_status_t status, const pmix_pro
         }
     }
 
-    /* setup for our own local callbacks */
-    chain = PMIX_NEW(pmix_event_chain_t);
-    chain->status = status;
-    chain->range = range;
-    if (NULL == source) {
-        PMIX_LOAD_PROCID(&chain->source, pmix_globals.myid.nspace, pmix_globals.myid.rank);
-    } else {
-        PMIX_LOAD_PROCID(&chain->source, source->nspace, source->rank);
-    }
-    /* we always leave space for event hdlr name and a callback object */
-    chain->nallocated = ninfo + 2;
-    PMIX_INFO_CREATE(chain->info, chain->nallocated);
-    /* prep the chain for processing */
-    pmix_prep_event_chain(chain, info, ninfo, true);
-
-    /* we need to cache this event so we can pass it into
-     * ourselves should someone later register for it */
-    cd = PMIX_NEW(pmix_notify_caddy_t);
-    cd->status = status;
-    PMIX_LOAD_PROCID(&cd->source, chain->source.nspace, chain->source.rank);
-    cd->range = chain->range;
-    if (0 < chain->ninfo) {
-        cd->ninfo = chain->ninfo;
-        PMIX_INFO_CREATE(cd->info, cd->ninfo);
-        cd->nondefault = chain->nondefault;
-        /* need to copy the info */
-        for (n = 0; n < cd->ninfo; n++) {
-            PMIX_INFO_XFER(&cd->info[n], &chain->info[n]);
+    if (dolocal) {
+        /* setup for our own local callbacks */
+        chain = PMIX_NEW(pmix_event_chain_t);
+        chain->status = status;
+        chain->range = range;
+        if (NULL == source) {
+            PMIX_LOAD_PROCID(&chain->source, pmix_globals.myid.nspace, pmix_globals.myid.rank);
+        } else {
+            PMIX_LOAD_PROCID(&chain->source, source->nspace, source->rank);
         }
-    }
-    if (NULL != chain->targets) {
-        cd->ntargets = chain->ntargets;
-        PMIX_PROC_CREATE(cd->targets, cd->ntargets);
-        memcpy(cd->targets, chain->targets, cd->ntargets * sizeof(pmix_proc_t));
-    }
-    if (NULL != chain->affected) {
-        cd->naffected = chain->naffected;
-        PMIX_PROC_CREATE(cd->affected, cd->naffected);
-        if (NULL == cd->affected) {
-            cd->naffected = 0;
-            rc = PMIX_ERR_NOMEM;
+        /* we always leave space for event hdlr name and a callback object */
+        chain->nallocated = ninfo + 2;
+        PMIX_INFO_CREATE(chain->info, chain->nallocated);
+        /* prep the chain for processing */
+        pmix_prep_event_chain(chain, info, ninfo, true);
+
+        /* we need to cache this event so we can pass it into
+         * ourselves should someone later register for it */
+        cd = PMIX_NEW(pmix_notify_caddy_t);
+        cd->status = status;
+        PMIX_LOAD_PROCID(&cd->source, chain->source.nspace, chain->source.rank);
+        cd->range = chain->range;
+        if (0 < chain->ninfo) {
+            cd->ninfo = chain->ninfo;
+            PMIX_INFO_CREATE(cd->info, cd->ninfo);
+            cd->nondefault = chain->nondefault;
+            /* need to copy the info */
+            for (n = 0; n < cd->ninfo; n++) {
+                PMIX_INFO_XFER(&cd->info[n], &chain->info[n]);
+            }
+        }
+        if (NULL != chain->targets) {
+            cd->ntargets = chain->ntargets;
+            PMIX_PROC_CREATE(cd->targets, cd->ntargets);
+            memcpy(cd->targets, chain->targets, cd->ntargets * sizeof(pmix_proc_t));
+        }
+        if (NULL != chain->affected) {
+            cd->naffected = chain->naffected;
+            PMIX_PROC_CREATE(cd->affected, cd->naffected);
+            if (NULL == cd->affected) {
+                cd->naffected = 0;
+                rc = PMIX_ERR_NOMEM;
+                goto cleanup;
+            }
+            memcpy(cd->affected, chain->affected, cd->naffected * sizeof(pmix_proc_t));
+        }
+        /* cache it */
+        rc = pmix_notify_event_cache(cd);
+        if (PMIX_SUCCESS != rc) {
+            PMIX_ERROR_LOG(rc);
+            PMIX_RELEASE(cd);
             goto cleanup;
         }
-        memcpy(cd->affected, chain->affected, cd->naffected * sizeof(pmix_proc_t));
+        chain->cached = true;
     }
-    /* cache it */
-    rc = pmix_notify_event_cache(cd);
-    if (PMIX_SUCCESS != rc) {
-        PMIX_ERROR_LOG(rc);
-        PMIX_RELEASE(cd);
-        goto cleanup;
-    }
-    chain->cached = true;
 
     if (PMIX_RANGE_PROC_LOCAL != range && NULL != msg) {
         /* if this is a "lost-connection" event, then there is no
-         * server to pass it to! */
-        if (PMIX_ERR_LOST_CONNECTION == status) {
+         * server to pass it to! Likewise, we don't pass it to
+         * ourselves */
+        if (PMIX_ERR_LOST_CONNECTION == status ||
+            pmix_globals.mypeer == pmix_client_globals.myserver) {
             PMIX_RELEASE(msg);
             goto local;
         }
@@ -303,8 +308,10 @@ static pmix_status_t notify_server_of_event(pmix_status_t status, const pmix_pro
     }
 
 local:
-    /* now notify any matching registered callbacks we have */
-    pmix_invoke_local_event_hdlr(chain);
+    if (dolocal) {
+        /* now notify any matching registered callbacks we have */
+        pmix_invoke_local_event_hdlr(chain);
+    }
 
     return PMIX_SUCCESS;
 
@@ -381,9 +388,11 @@ static void cycle_events(int sd, short args, void *cbdata)
     chain->results = newinfo;
     chain->nresults = cnt;
     /* clear any loaded name and object */
-    chain->ninfo = chain->nallocated - 2;
-    PMIX_INFO_DESTRUCT(&chain->info[chain->nallocated - 2]);
-    PMIX_INFO_DESTRUCT(&chain->info[chain->nallocated - 1]);
+    if (chain->nallocated > chain->ninfo) {
+        chain->ninfo = chain->nallocated - 2;
+        PMIX_INFO_DESTRUCT(&chain->info[chain->nallocated - 2]);
+        PMIX_INFO_DESTRUCT(&chain->info[chain->nallocated - 1]);
+    }
     // call their interim cbfunc
     if (NULL != chain->opcbfunc) {
         chain->opcbfunc(chain->interim_status, chain->cbdata);
@@ -391,11 +400,15 @@ static void cycle_events(int sd, short args, void *cbdata)
 
     /* if the caller indicates that the chain is completed,
      * or we completed the "last" event */
-    if (PMIX_EVENT_ACTION_COMPLETE == chain->interim_status
-        || PMIX_EVENT_ORDER_LAST_OVERALL == chain->evhdlr->precedence || chain->endchain) {
+    if (PMIX_EVENT_ACTION_COMPLETE == chain->interim_status ||
+        PMIX_EVENT_ORDER_LAST_OVERALL == chain->evhdlr->precedence || chain->endchain) {
         if (PMIX_EVENT_ACTION_COMPLETE == chain->interim_status) {
             chain->interim_status = PMIX_SUCCESS;
         }
+        if (chain->evhdlr->oneshot) {
+            /* remove this handler */
+            pmix_deregister_event_hdlr(chain->evhdlr->index, NULL);
+        }
         goto complete;
     }
     item = NULL;
@@ -409,8 +422,7 @@ static void cycle_events(int sd, short args, void *cbdata)
         } else {
             item = &chain->evhdlr->super;
         }
-        while (pmix_list_get_end(&pmix_globals.events.single_events)
-               != (item = pmix_list_get_next(item))) {
+        while (pmix_list_get_end(&pmix_globals.events.single_events) != (item = pmix_list_get_next(item))) {
             nxt = (pmix_event_hdlr_t *) item;
             if (nxt->codes[0] == chain->status && pmix_notify_check_range(&nxt->rng, &chain->source)
                 && pmix_notify_check_affected(nxt->affected, nxt->naffected, chain->affected,
@@ -499,8 +511,7 @@ static void cycle_events(int sd, short args, void *cbdata)
         } else if (NULL == item) {
             item = &chain->evhdlr->super;
         }
-        if (pmix_list_get_end(&pmix_globals.events.default_events)
-            != (item = pmix_list_get_next(item))) {
+        if (pmix_list_get_end(&pmix_globals.events.default_events) != (item = pmix_list_get_next(item))) {
             nxt = (pmix_event_hdlr_t *) item;
             /* if this event handler provided a range, check to see if
              * the source fits within it */
@@ -687,7 +698,8 @@ void pmix_invoke_local_event_hdlr(pmix_event_chain_t *chain)
             }
         }
         if (!found) {
-            pmix_output_verbose(8, pmix_client_globals.event_output, "%s %s:%d",
+            pmix_output_verbose(8, pmix_client_globals.event_output,
+                                "%s Ignoring event %s:%d",
                                 PMIX_NAME_PRINT(&pmix_globals.myid), __FILE__, __LINE__);
             goto complete;
         }
@@ -827,7 +839,6 @@ void pmix_invoke_local_event_hdlr(pmix_event_chain_t *chain)
     }
     pmix_output_verbose(8, pmix_client_globals.event_output, "%s %s:%d",
                         PMIX_NAME_PRINT(&pmix_globals.myid),
-
                         __FILE__, __LINE__);
 
     /* if we got here, then nothing was found */
@@ -1089,6 +1100,10 @@ static void _notify_client_event(int sd, short args, void *cbdata)
                     if (PMIX_CHECK_PROCID(&cd->source, &pr->peer->info->pname)) {
                         continue;
                     }
+                    /* don't notify ourselves - we handle this internally */
+                    if (PMIX_CHECK_PROCID(&pmix_globals.myid, &pr->peer->info->pname)) {
+                        continue;
+                    }
                     /* if we have already notified this client, then don't do it again */
                     matched = false;
                     PMIX_LIST_FOREACH (nm, &trk, pmix_namelist_t) {
@@ -1169,6 +1184,14 @@ static void _notify_client_event(int sd, short args, void *cbdata)
                             continue;
                         }
                     }
+                    /* pack the range in case they need to relay */
+                    PMIX_BFROPS_PACK(rc, pr->peer, bfr, &cd->range, 1, PMIX_DATA_RANGE);
+                    if (PMIX_SUCCESS != rc) {
+                        PMIX_ERROR_LOG(rc);
+                        PMIX_RELEASE(bfr);
+                        continue;
+                    }
+
                     PMIX_SERVER_QUEUE_REPLY(rc, pr->peer, 0, bfr);
                     if (PMIX_SUCCESS != rc) {
                         PMIX_RELEASE(bfr);
@@ -1188,7 +1211,8 @@ static void _notify_client_event(int sd, short args, void *cbdata)
             }
         }
         PMIX_LIST_DESTRUCT(&trk);
-        if (PMIX_RANGE_LOCAL != cd->range && PMIX_CHECK_PROCID(&cd->source, &pmix_globals.myid)) {
+        if (PMIX_RANGE_LOCAL != cd->range &&
+            PMIX_CHECK_PROCID(&cd->source, &pmix_globals.myid)) {
             /* if we are the source, then we need to post this upwards as
              * well so the host RM can broadcast it as necessary */
             if (NULL != pmix_host_server.notify_event) {
@@ -1349,12 +1373,11 @@ void pmix_event_timeout_cb(int fd, short flags, void *arg)
     /* remove it from the list */
     pmix_list_remove_item(&pmix_globals.cached_events, &ch->super);
 
-    /* protect the chain */
-    PMIX_RETAIN(ch);
-
     /* process this event thru the regular channels */
-    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) && !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
-        pmix_server_notify_client_of_event(ch->status, &ch->source, ch->range, ch->info, ch->ninfo,
+    if (PMIX_PEER_IS_SERVER(pmix_globals.mypeer) &&
+        !PMIX_PEER_IS_LAUNCHER(pmix_globals.mypeer)) {
+        pmix_server_notify_client_of_event(ch->status, &ch->source, ch->range,
+                                           ch->info, ch->ninfo,
                                            ch->final_cbfunc, ch->final_cbdata);
     } else {
         pmix_invoke_local_event_hdlr(ch);
@@ -1427,6 +1450,7 @@ static void sevcon(pmix_event_hdlr_t *p)
     p->name = NULL;
     p->index = UINT_MAX;
     p->precedence = PMIX_EVENT_ORDER_NONE;
+    p->oneshot = false;
     p->locator = NULL;
     p->rng.range = PMIX_RANGE_UNDEF;
     p->rng.procs = NULL;
@@ -1487,7 +1511,9 @@ static void evdes(pmix_events_t *p)
     PMIX_LIST_DESTRUCT(&p->multi_events);
     PMIX_LIST_DESTRUCT(&p->default_events);
 }
-PMIX_CLASS_INSTANCE(pmix_events_t, pmix_object_t, evcon, evdes);
+PMIX_CLASS_INSTANCE(pmix_events_t,
+                    pmix_object_t,
+                    evcon, evdes);
 
 static void chcon(pmix_event_chain_t *p)
 {
@@ -1534,4 +1560,6 @@ static void chdes(pmix_event_chain_t *p)
         PMIX_INFO_FREE(p->results, p->nresults);
     }
 }
-PMIX_CLASS_INSTANCE(pmix_event_chain_t, pmix_list_item_t, chcon, chdes);
+PMIX_CLASS_INSTANCE(pmix_event_chain_t,
+                    pmix_list_item_t,
+                    chcon, chdes);
