@@ -14,7 +14,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015-2020 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -26,14 +26,14 @@
  */
 #include "src/include/pmix_config.h"
 
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 
 #ifdef HAVE_STRING_H
 #    include <string.h>
 #endif
 
 #include "src/class/pmix_list.h"
-#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/base/pmix_mca_base_framework.h"
 #include "src/mca/base/pmix_mca_base_var.h"
 #include "src/mca/bfrops/base/base.h"
@@ -63,23 +63,21 @@ int pmix_bfrops_base_output = 0;
 
 static int pmix_bfrop_register(pmix_mca_base_register_flag_t flags)
 {
+    PMIX_HIDE_UNUSED_PARAMS(flags);
+
     if (PMIX_MCA_BASE_REGISTER_DEFAULT == flags) {
         /* do something to silence warning */
-        int count = 0;
-        ++count;
     }
     pmix_bfrops_globals.initial_size = PMIX_BFROP_DEFAULT_INITIAL_SIZE;
     pmix_mca_base_var_register("pmix", "bfrops", "base", "initial_size", "Initial size of a buffer",
-                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
-                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T,
                                &pmix_bfrops_globals.initial_size);
 
     pmix_bfrops_globals.threshold_size = PMIX_BFROP_DEFAULT_THRESHOLD_SIZE;
     pmix_mca_base_var_register("pmix", "bfrops", "base", "threshold_size",
                                "Size at which we switch from extending a buffer by doubling to "
                                "extending by a smaller value",
-                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
-                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+                               PMIX_MCA_BASE_VAR_TYPE_SIZE_T,
                                &pmix_bfrops_globals.threshold_size);
 
 #if PMIX_ENABLE_DEBUG
@@ -88,8 +86,7 @@ static int pmix_bfrop_register(pmix_mca_base_register_flag_t flags)
     pmix_bfrops_globals.default_type = PMIX_BFROP_BUFFER_NON_DESC;
 #endif
     pmix_mca_base_var_register("pmix", "bfrops", "base", "default_type", "Default type for buffers",
-                               PMIX_MCA_BASE_VAR_TYPE_INT, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE,
-                               PMIX_INFO_LVL_2, PMIX_MCA_BASE_VAR_SCOPE_READONLY,
+                               PMIX_MCA_BASE_VAR_TYPE_INT,
                                &pmix_bfrops_globals.default_type);
     return PMIX_SUCCESS;
 }
@@ -124,7 +121,7 @@ static pmix_status_t pmix_bfrop_open(pmix_mca_base_open_flag_t flags)
 
 PMIX_MCA_BASE_FRAMEWORK_DECLARE(pmix, bfrops, "PMIx Buffer Operations", pmix_bfrop_register,
                                 pmix_bfrop_open, pmix_bfrop_close,
-                                mca_bfrops_base_static_components,
+                                pmix_mca_bfrops_base_static_components,
                                 PMIX_MCA_BASE_FRAMEWORK_FLAG_DEFAULT);
 
 static void moddes(pmix_bfrops_base_active_module_t *p)
@@ -141,8 +138,9 @@ PMIX_CLASS_INSTANCE(pmix_bfrops_base_active_module_t, pmix_list_item_t, NULL, mo
 /** Value **/
 static void pmix_buffer_construct(pmix_buffer_t *buffer)
 {
-    /** set the default buffer type */
-    buffer->type = pmix_bfrops_globals.default_type;
+    /** set the buffer type  to UNDEF so the first pack operation
+     * can correctly set it */
+    buffer->type = PMIX_BFROP_BUFFER_UNDEF;
 
     /* Make everything NULL to begin with */
     buffer->base_ptr = buffer->pack_ptr = buffer->unpack_ptr = NULL;
