@@ -15,7 +15,7 @@
  *                         and Technology (RIST).  All rights reserved.
  * Copyright (c) 2016-2019 Mellanox Technologies, Inc.
  *                         All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -25,12 +25,12 @@
 
 #include "src/include/pmix_config.h"
 
+#include "src/hwloc/pmix_hwloc.h"
 #include "src/include/pmix_globals.h"
-#include "src/mca/ploc/ploc.h"
 #include "src/mca/preg/preg.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/output.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_output.h"
 
 #include "src/mca/bfrops/base/base.h"
 #include "src/mca/bfrops/bfrops_types.h"
@@ -54,8 +54,9 @@ static pmix_status_t pmix_bfrops_base_unpack_buffer(pmix_pointer_array_t *regtyp
         }
         /* if the data types don't match, then return an error */
         if (type != local_type) {
-            pmix_output(0, "PMIX bfrop:unpack: got type %d when expecting type %d", local_type,
-                        type);
+            pmix_output(0, "PMIX bfrop:unpack: got type %s when expecting type %s",
+                        PMIx_Data_type_string(local_type),
+                        PMIx_Data_type_string(type));
             return PMIX_ERR_PACK_MISMATCH;
         }
     }
@@ -160,12 +161,7 @@ pmix_status_t pmix_bfrops_base_unpack_bool(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_bool * %d\n", (int) *num_vals);
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_BOOL != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     /* check to see if there's enough data in buffer */
     if (pmix_bfrop_too_small(buffer, *num_vals)) {
@@ -199,9 +195,7 @@ pmix_status_t pmix_bfrops_base_unpack_int(pmix_pointer_array_t *regtypes, pmix_b
     pmix_status_t ret;
     pmix_data_type_t remote_type;
 
-    if (PMIX_INT != type && PMIX_UINT != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     if (PMIX_SUCCESS != (ret = pmix_bfrop_get_data_type(regtypes, buffer, &remote_type))) {
         return ret;
@@ -232,6 +226,8 @@ pmix_status_t pmix_bfrops_base_unpack_sizet(pmix_pointer_array_t *regtypes, pmix
         return PMIX_ERR_BAD_PARAM;
     }
 
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     if (PMIX_SUCCESS != (ret = pmix_bfrop_get_data_type(regtypes, buffer, &remote_type))) {
         PMIX_ERROR_LOG(ret);
         return ret;
@@ -260,9 +256,7 @@ pmix_status_t pmix_bfrops_base_unpack_pid(pmix_pointer_array_t *regtypes, pmix_b
     pmix_status_t ret;
     pmix_data_type_t remote_type;
 
-    if (PMIX_PID != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     if (PMIX_SUCCESS != (ret = pmix_bfrop_get_data_type(regtypes, buffer, &remote_type))) {
         return ret;
@@ -291,12 +285,7 @@ pmix_status_t pmix_bfrops_base_unpack_byte(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_byte * %d\n", (int) *num_vals);
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_BYTE != type && PMIX_UINT8 != type && PMIX_INT8 != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     /* check to see if there's enough data in buffer */
     if (pmix_bfrop_too_small(buffer, *num_vals)) {
@@ -321,12 +310,7 @@ pmix_status_t pmix_bfrops_base_unpack_int16(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_int16 * %d\n", (int) *num_vals);
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_INT16 != type && PMIX_UINT16 != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     /* check to see if there's enough data in buffer */
     if (pmix_bfrop_too_small(buffer, (*num_vals) * sizeof(tmp))) {
@@ -353,12 +337,7 @@ pmix_status_t pmix_bfrops_base_unpack_int32(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_int32 * %d\n", (int) *num_vals);
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_INT32 != type && PMIX_UINT32 != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     /* check to see if there's enough data in buffer */
     if (pmix_bfrop_too_small(buffer, (*num_vals) * sizeof(tmp))) {
@@ -382,9 +361,8 @@ pmix_status_t pmix_bfrops_base_unpack_datatype(pmix_pointer_array_t *regtypes,
 {
     pmix_status_t ret;
 
-    if (PMIX_DATA_TYPE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_INT16, regtypes);
     return ret;
 }
@@ -398,12 +376,7 @@ pmix_status_t pmix_bfrops_base_unpack_int64(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_int64 * %d\n", (int) *num_vals);
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_INT64 != type && PMIX_UINT64 != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     /* check to see if there's enough data in buffer */
     if (pmix_bfrop_too_small(buffer, (*num_vals) * sizeof(tmp))) {
@@ -428,9 +401,7 @@ pmix_status_t pmix_bfrops_base_unpack_string(pmix_pointer_array_t *regtypes, pmi
     int32_t i, len, n = 1;
     char **sdest = (char **) dest;
 
-    if (PMIX_STRING != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     for (i = 0; i < (*num_vals); ++i) {
         PMIX_BFROPS_UNPACK_TYPE(ret, buffer, &len, &n, PMIX_INT32, regtypes);
@@ -465,9 +436,7 @@ pmix_status_t pmix_bfrops_base_unpack_float(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_float * %d\n", (int) *num_vals);
 
-    if (PMIX_FLOAT != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     /* unpack the data */
     for (i = 0; i < (*num_vals); ++i) {
@@ -497,9 +466,7 @@ pmix_status_t pmix_bfrops_base_unpack_double(pmix_pointer_array_t *regtypes, pmi
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_double * %d\n", (int) *num_vals);
 
-    if (PMIX_DOUBLE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     /* unpack the data */
     for (i = 0; i < (*num_vals); ++i) {
@@ -529,9 +496,7 @@ pmix_status_t pmix_bfrops_base_unpack_timeval(pmix_pointer_array_t *regtypes, pm
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_timeval * %d\n", (int) *num_vals);
 
-    if (PMIX_TIMEVAL != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     /* unpack the data */
     for (i = 0; i < (*num_vals); ++i) {
@@ -562,9 +527,7 @@ pmix_status_t pmix_bfrops_base_unpack_time(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_time * %d\n", (int) *num_vals);
 
-    if (PMIX_TIME != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     /* unpack the data */
     for (i = 0; i < (*num_vals); ++i) {
@@ -587,9 +550,7 @@ pmix_status_t pmix_bfrops_base_unpack_status(pmix_pointer_array_t *regtypes, pmi
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack_status * %d\n", (int) *num_vals);
 
-    if (PMIX_STATUS != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     /* unpack the data */
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_INT32, regtypes);
@@ -609,125 +570,126 @@ pmix_status_t pmix_bfrops_base_unpack_val(pmix_pointer_array_t *regtypes, pmix_b
 
     m = 1;
     switch (val->type) {
-    case PMIX_UNDEF:
-        break;
-    case PMIX_PROC:
-        /* this field is now a pointer, so we must allocate storage for it */
-        PMIX_PROC_CREATE(val->data.proc, m);
-        if (NULL == val->data.proc) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.proc, &m, PMIX_PROC, regtypes);
-        break;
-    case PMIX_PROC_INFO:
-        /* this is now a pointer, so allocate storage for it */
-        PMIX_PROC_INFO_CREATE(val->data.pinfo, 1);
-        if (NULL == val->data.pinfo) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.pinfo, &m, PMIX_PROC_INFO, regtypes);
-        break;
-    case PMIX_DATA_ARRAY:
-        /* this is now a pointer, so allocate storage for it */
-        val->data.darray = (pmix_data_array_t *) malloc(sizeof(pmix_data_array_t));
-        if (NULL == val->data.darray) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.darray, &m, PMIX_DATA_ARRAY, regtypes);
-        break;
-    case PMIX_REGATTR:
-        val->data.ptr = (pmix_regattr_t *) calloc(1, sizeof(pmix_regattr_t));
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ptr, &m, PMIX_REGATTR, regtypes);
-        return ret;
-    case PMIX_COORD:
-        val->data.coord = (pmix_coord_t *) calloc(1, sizeof(pmix_coord_t));
-        if (NULL == val->data.coord) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.coord, &m, PMIX_COORD, regtypes);
-        return ret;
-    case PMIX_TOPO:
-        PMIX_TOPOLOGY_CREATE(val->data.topo, 1);
-        if (NULL == val->data.topo) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.topo, &m, PMIX_TOPO, regtypes);
-        return ret;
-    case PMIX_PROC_CPUSET:
-        PMIX_CPUSET_CREATE(val->data.cpuset, 1);
-        if (NULL == val->data.cpuset) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.cpuset, &m, PMIX_PROC_CPUSET, regtypes);
-        return ret;
-    case PMIX_GEOMETRY:
-        PMIX_GEOMETRY_CREATE(val->data.geometry, 1);
-        if (NULL == val->data.geometry) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.geometry, &m, PMIX_GEOMETRY, regtypes);
-        return ret;
-    case PMIX_DEVICE_DIST:
-        PMIX_DEVICE_DIST_CREATE(val->data.devdist, 1);
-        if (NULL == val->data.devdist) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.devdist, &m, PMIX_DEVICE_DIST, regtypes);
-        return ret;
-    case PMIX_ENDPOINT:
-        PMIX_ENDPOINT_CREATE(val->data.endpoint, 1);
-        if (NULL == val->data.endpoint) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.endpoint, &m, PMIX_ENDPOINT, regtypes);
-        return ret;
-    case PMIX_PROC_NSPACE:
-        PMIX_PROC_CREATE(val->data.proc, 1);
-        if (NULL == val->data.proc) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, &val->data.proc->nspace, &m, PMIX_PROC_NSPACE,
-                                regtypes);
-        return ret;
-    case PMIX_PROC_STATS:
-        PMIX_PROC_STATS_CREATE(val->data.pstats, 1);
-        if (NULL == val->data.pstats) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.pstats, &m, PMIX_PROC_STATS, regtypes);
-        return ret;
-    case PMIX_DISK_STATS:
-        PMIX_DISK_STATS_CREATE(val->data.dkstats, 1);
-        if (NULL == val->data.dkstats) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.dkstats, &m, PMIX_DISK_STATS, regtypes);
-        return ret;
-    case PMIX_NET_STATS:
-        PMIX_NET_STATS_CREATE(val->data.netstats, 1);
-        if (NULL == val->data.netstats) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.netstats, &m, PMIX_NET_STATS, regtypes);
-    case PMIX_NODE_STATS:
-        PMIX_NODE_STATS_CREATE(val->data.ndstats, 1);
-        if (NULL == val->data.ndstats) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ndstats, &m, PMIX_NODE_STATS, regtypes);
-        return ret;
-    case PMIX_DATA_BUFFER:
-        PMIX_DATA_BUFFER_CREATE(val->data.ptr);
-        if (NULL == val->data.ptr) {
-            return PMIX_ERR_NOMEM;
-        }
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ptr, &m, PMIX_DATA_BUFFER, regtypes);
-        return ret;
-    default:
-        PMIX_BFROPS_UNPACK_TYPE(ret, buffer, &val->data, &m, val->type, regtypes);
-        if (PMIX_ERR_UNKNOWN_DATA_TYPE == ret) {
-            pmix_output(0, "UNPACK-PMIX-VALUE: UNSUPPORTED TYPE %d", (int) val->type);
-        }
+        case PMIX_UNDEF:
+            break;
+        case PMIX_PROC:
+            /* this field is now a pointer, so we must allocate storage for it */
+            PMIX_PROC_CREATE(val->data.proc, m);
+            if (NULL == val->data.proc) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.proc, &m, PMIX_PROC, regtypes);
+            break;
+        case PMIX_PROC_INFO:
+            /* this is now a pointer, so allocate storage for it */
+            PMIX_PROC_INFO_CREATE(val->data.pinfo, 1);
+            if (NULL == val->data.pinfo) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.pinfo, &m, PMIX_PROC_INFO, regtypes);
+            break;
+        case PMIX_DATA_ARRAY:
+            /* this is now a pointer, so allocate storage for it */
+            val->data.darray = (pmix_data_array_t *) malloc(sizeof(pmix_data_array_t));
+            if (NULL == val->data.darray) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.darray, &m, PMIX_DATA_ARRAY, regtypes);
+            break;
+        case PMIX_REGATTR:
+            val->data.ptr = (pmix_regattr_t *) calloc(1, sizeof(pmix_regattr_t));
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ptr, &m, PMIX_REGATTR, regtypes);
+            return ret;
+        case PMIX_COORD:
+            val->data.coord = (pmix_coord_t *) calloc(1, sizeof(pmix_coord_t));
+            if (NULL == val->data.coord) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.coord, &m, PMIX_COORD, regtypes);
+            return ret;
+        case PMIX_TOPO:
+            PMIX_TOPOLOGY_CREATE(val->data.topo, 1);
+            if (NULL == val->data.topo) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.topo, &m, PMIX_TOPO, regtypes);
+            return ret;
+        case PMIX_PROC_CPUSET:
+            PMIX_CPUSET_CREATE(val->data.cpuset, 1);
+            if (NULL == val->data.cpuset) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.cpuset, &m, PMIX_PROC_CPUSET, regtypes);
+            return ret;
+        case PMIX_GEOMETRY:
+            PMIX_GEOMETRY_CREATE(val->data.geometry, 1);
+            if (NULL == val->data.geometry) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.geometry, &m, PMIX_GEOMETRY, regtypes);
+            return ret;
+        case PMIX_DEVICE_DIST:
+            PMIX_DEVICE_DIST_CREATE(val->data.devdist, 1);
+            if (NULL == val->data.devdist) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.devdist, &m, PMIX_DEVICE_DIST, regtypes);
+            return ret;
+        case PMIX_ENDPOINT:
+            PMIX_ENDPOINT_CREATE(val->data.endpoint, 1);
+            if (NULL == val->data.endpoint) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.endpoint, &m, PMIX_ENDPOINT, regtypes);
+            return ret;
+        case PMIX_PROC_NSPACE:
+            PMIX_PROC_CREATE(val->data.proc, 1);
+            if (NULL == val->data.proc) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, &val->data.proc->nspace, &m, PMIX_PROC_NSPACE,
+                                    regtypes);
+            return ret;
+        case PMIX_PROC_STATS:
+            PMIX_PROC_STATS_CREATE(val->data.pstats, 1);
+            if (NULL == val->data.pstats) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.pstats, &m, PMIX_PROC_STATS, regtypes);
+            return ret;
+        case PMIX_DISK_STATS:
+            PMIX_DISK_STATS_CREATE(val->data.dkstats, 1);
+            if (NULL == val->data.dkstats) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.dkstats, &m, PMIX_DISK_STATS, regtypes);
+            return ret;
+        case PMIX_NET_STATS:
+            PMIX_NET_STATS_CREATE(val->data.netstats, 1);
+            if (NULL == val->data.netstats) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.netstats, &m, PMIX_NET_STATS, regtypes);
+            return ret;
+        case PMIX_NODE_STATS:
+            PMIX_NODE_STATS_CREATE(val->data.ndstats, 1);
+            if (NULL == val->data.ndstats) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ndstats, &m, PMIX_NODE_STATS, regtypes);
+            return ret;
+        case PMIX_DATA_BUFFER:
+            PMIX_DATA_BUFFER_CREATE(val->data.ptr);
+            if (NULL == val->data.ptr) {
+                return PMIX_ERR_NOMEM;
+            }
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, val->data.ptr, &m, PMIX_DATA_BUFFER, regtypes);
+            return ret;
+        default:
+            PMIX_BFROPS_UNPACK_TYPE(ret, buffer, &val->data, &m, val->type, regtypes);
+            if (PMIX_ERR_UNKNOWN_DATA_TYPE == ret) {
+                pmix_output(0, "UNPACK-PMIX-VALUE: UNSUPPORTED TYPE %d", (int) val->type);
+            }
     }
 
     return ret;
@@ -743,9 +705,7 @@ pmix_status_t pmix_bfrops_base_unpack_value(pmix_pointer_array_t *regtypes, pmix
     ptr = (pmix_value_t *) dest;
     n = *num_vals;
 
-    if (PMIX_VALUE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     for (i = 0; i < n; ++i) {
         /* unpack the type */
@@ -773,9 +733,7 @@ pmix_status_t pmix_bfrops_base_unpack_info(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d info", *num_vals);
 
-    if (PMIX_INFO != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_info_t *) dest;
     n = *num_vals;
@@ -830,9 +788,7 @@ pmix_status_t pmix_bfrops_base_unpack_pdata(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d pdata", *num_vals);
 
-    if (PMIX_PDATA != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_pdata_t *) dest;
     n = *num_vals;
@@ -889,9 +845,7 @@ pmix_status_t pmix_bfrops_base_unpack_buf(pmix_pointer_array_t *regtypes, pmix_b
     ptr = (pmix_buffer_t *) dest;
     n = *num_vals;
 
-    if (PMIX_BUFFER != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     for (i = 0; i < n; ++i) {
         PMIX_CONSTRUCT(&ptr[i], pmix_buffer_t);
@@ -939,9 +893,7 @@ pmix_status_t pmix_bfrops_base_unpack_proc(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d procs", *num_vals);
 
-    if (PMIX_PROC != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_proc_t *) dest;
     n = *num_vals;
@@ -985,9 +937,7 @@ pmix_status_t pmix_bfrops_base_unpack_app(pmix_pointer_array_t *regtypes, pmix_b
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d apps", *num_vals);
 
-    if (PMIX_APP != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_app_t *) dest;
     n = *num_vals;
@@ -1087,9 +1037,7 @@ pmix_status_t pmix_bfrops_base_unpack_kval(pmix_pointer_array_t *regtypes, pmix_
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d kvals", *num_vals);
 
-    if (PMIX_KVAL != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_kval_t *) dest;
     n = *num_vals;
@@ -1119,9 +1067,7 @@ pmix_status_t pmix_bfrops_base_unpack_persist(pmix_pointer_array_t *regtypes, pm
 {
     pmix_status_t ret;
 
-    if (PMIX_PERSIST != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_BYTE, regtypes);
     return ret;
@@ -1137,9 +1083,7 @@ pmix_status_t pmix_bfrops_base_unpack_bo(pmix_pointer_array_t *regtypes, pmix_bu
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d byte_object", *num_vals);
 
-    if (PMIX_BYTE_OBJECT != type && PMIX_COMPRESSED_BYTE_OBJECT != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_byte_object_t *) dest;
     n = *num_vals;
@@ -1171,15 +1115,7 @@ pmix_status_t pmix_bfrops_base_unpack_ptr(pmix_pointer_array_t *regtypes, pmix_b
     int32_t cnt = 1;
     pmix_status_t ret;
 
-    if (NULL == dest) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (NULL == num_vals) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_POINTER != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(dest, num_vals, type);
 
     /* it obviously makes no sense to pack a pointer and
      * send it somewhere else, so we just unpack the sentinel */
@@ -1192,9 +1128,7 @@ pmix_status_t pmix_bfrops_base_unpack_scope(pmix_pointer_array_t *regtypes, pmix
 {
     pmix_status_t ret;
 
-    if (PMIX_SCOPE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1205,9 +1139,7 @@ pmix_status_t pmix_bfrops_base_unpack_range(pmix_pointer_array_t *regtypes, pmix
 {
     pmix_status_t ret;
 
-    if (PMIX_DATA_RANGE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1218,9 +1150,7 @@ pmix_status_t pmix_bfrops_base_unpack_cmd(pmix_pointer_array_t *regtypes, pmix_b
 {
     pmix_status_t ret;
 
-    if (PMIX_COMMAND != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1232,9 +1162,7 @@ pmix_status_t pmix_bfrops_base_unpack_info_directives(pmix_pointer_array_t *regt
 {
     pmix_status_t ret;
 
-    if (PMIX_INFO_DIRECTIVES != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT32, regtypes);
     return ret;
@@ -1245,9 +1173,7 @@ pmix_status_t pmix_bfrops_base_unpack_pstate(pmix_pointer_array_t *regtypes, pmi
 {
     pmix_status_t ret;
 
-    if (PMIX_PROC_STATE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1263,9 +1189,7 @@ pmix_status_t pmix_bfrops_base_unpack_pinfo(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d pinfo", *num_vals);
 
-    if (PMIX_PROC_INFO != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_proc_info_t *) dest;
     n = *num_vals;
@@ -1318,9 +1242,7 @@ pmix_status_t pmix_bfrops_base_unpack_darray(pmix_pointer_array_t *regtypes, pmi
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d data arrays", *num_vals);
 
-    if (PMIX_DATA_ARRAY != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_data_array_t *) dest;
     n = *num_vals;
@@ -1364,9 +1286,7 @@ pmix_status_t pmix_bfrops_base_unpack_rank(pmix_pointer_array_t *regtypes, pmix_
 {
     pmix_status_t ret;
 
-    if (PMIX_PROC_RANK != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT32, regtypes);
     return ret;
@@ -1383,9 +1303,7 @@ pmix_status_t pmix_bfrops_base_unpack_query(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d queries", *num_vals);
 
-    if (PMIX_QUERY != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_query_t *) dest;
     n = *num_vals;
@@ -1435,9 +1353,7 @@ pmix_status_t pmix_bfrops_base_unpack_alloc_directive(pmix_pointer_array_t *regt
 {
     pmix_status_t ret;
 
-    if (PMIX_ALLOC_DIRECTIVE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1449,9 +1365,7 @@ pmix_status_t pmix_bfrops_base_unpack_iof_channel(pmix_pointer_array_t *regtypes
 {
     pmix_status_t ret;
 
-    if (PMIX_IOF_CHANNEL != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT16, regtypes);
     return ret;
@@ -1467,9 +1381,7 @@ pmix_status_t pmix_bfrops_base_unpack_envar(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d envars", *num_vals);
 
-    if (PMIX_ENVAR != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_envar_t *) dest;
     n = *num_vals;
@@ -1508,9 +1420,7 @@ pmix_status_t pmix_bfrops_base_unpack_coord(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d coordinates", *num_vals);
 
-    if (PMIX_COORD != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_coord_t *) dest;
     n = *num_vals;
@@ -1553,9 +1463,7 @@ pmix_status_t pmix_bfrops_base_unpack_regattr(pmix_pointer_array_t *regtypes, pm
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d regattrs", *num_vals);
 
-    if (PMIX_REGATTR != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_regattr_t *) dest;
     n = *num_vals;
@@ -1621,9 +1529,7 @@ pmix_status_t pmix_bfrops_base_unpack_regex(pmix_pointer_array_t *regtypes, pmix
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d regex", *num_vals);
 
-    if (PMIX_REGEX != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(regtypes, type);
 
     ptr = (char **) dest;
     n = *num_vals;
@@ -1644,9 +1550,7 @@ pmix_status_t pmix_bfrops_base_unpack_jobstate(pmix_pointer_array_t *regtypes,
 {
     pmix_status_t ret;
 
-    if (PMIX_JOB_STATE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1658,9 +1562,7 @@ pmix_status_t pmix_bfrops_base_unpack_linkstate(pmix_pointer_array_t *regtypes,
 {
     pmix_status_t ret;
 
-    if (PMIX_LINK_STATE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT8, regtypes);
     return ret;
@@ -1676,15 +1578,13 @@ pmix_status_t pmix_bfrops_base_unpack_cpuset(pmix_pointer_array_t *regtypes, pmi
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d cpuset", *num_vals);
 
-    if (PMIX_PROC_CPUSET != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_cpuset_t *) dest;
     n = *num_vals;
 
     for (i = 0; i < n; ++i) {
-        ret = pmix_ploc.unpack_cpuset(buffer, &ptr[i], regtypes);
+        ret = pmix_hwloc_unpack_cpuset(buffer, &ptr[i], regtypes);
         if (PMIX_SUCCESS != ret) {
             *num_vals = 0;
             return ret;
@@ -1704,9 +1604,7 @@ pmix_status_t pmix_bfrops_base_unpack_geometry(pmix_pointer_array_t *regtypes,
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d geometry", *num_vals);
 
-    if (PMIX_GEOMETRY != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_geometry_t *) dest;
     n = *num_vals;
@@ -1765,9 +1663,7 @@ pmix_status_t pmix_bfrops_base_unpack_devdist(pmix_pointer_array_t *regtypes, pm
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d device distances", *num_vals);
 
-    if (PMIX_DEVICE_DIST != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_device_distance_t *) dest;
     n = *num_vals;
@@ -1820,9 +1716,7 @@ pmix_status_t pmix_bfrops_base_unpack_endpoint(pmix_pointer_array_t *regtypes,
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d endpts", *num_vals);
 
-    if (PMIX_ENDPOINT != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_endpoint_t *) dest;
     n = *num_vals;
@@ -1872,15 +1766,13 @@ pmix_status_t pmix_bfrops_base_unpack_topology(pmix_pointer_array_t *regtypes,
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d topology", *num_vals);
 
-    if (PMIX_TOPO != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_topology_t *) dest;
     n = *num_vals;
 
     for (i = 0; i < n; ++i) {
-        ret = pmix_ploc.unpack_topology(buffer, &ptr[i], regtypes);
+        ret = pmix_hwloc_unpack_topology(buffer, &ptr[i], regtypes);
         if (PMIX_SUCCESS != ret) {
             *num_vals = 0;
             return ret;
@@ -1897,9 +1789,7 @@ pmix_status_t pmix_bfrops_base_unpack_devtype(pmix_pointer_array_t *regtypes, pm
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d device types", *num_vals);
 
-    if (PMIX_DEVTYPE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT64, regtypes);
 
@@ -1915,9 +1805,7 @@ pmix_status_t pmix_bfrops_base_unpack_locality(pmix_pointer_array_t *regtypes,
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d locality", *num_vals);
 
-    if (PMIX_LOCTYPE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT16, regtypes);
 
@@ -1935,9 +1823,7 @@ pmix_status_t pmix_bfrops_base_unpack_nspace(pmix_pointer_array_t *regtypes, pmi
     pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
                         "pmix_bfrop_unpack: %d nspace", *num_vals);
 
-    if (PMIX_PROC_NSPACE != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     ptr = (pmix_nspace_t *) dest;
     n = *num_vals;
@@ -1965,12 +1851,7 @@ pmix_status_t pmix_bfrops_base_unpack_pstats(pmix_pointer_array_t *regtypes, pmi
     ptr = (pmix_proc_stats_t *) dest;
     n = *num_vals;
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_PROC_STATS != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     for (i = 0; i < n; ++i) {
         m = 1;
@@ -2069,12 +1950,8 @@ pmix_status_t pmix_bfrops_base_unpack_dkstats(pmix_pointer_array_t *regtypes, pm
     pmix_status_t ret;
     pmix_disk_stats_t *ptr = (pmix_disk_stats_t *) dest;
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_DISK_STATS != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
     /* unpack them */
     n = *num_vals;
     for (i = 0; i < n; i++) {
@@ -2169,12 +2046,7 @@ pmix_status_t pmix_bfrops_base_unpack_netstats(pmix_pointer_array_t *regtypes,
     int32_t i, m, n;
     int ret;
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_NET_STATS != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     n = *num_vals;
     for (i = 0; i < n; i++) {
@@ -2231,12 +2103,7 @@ pmix_status_t pmix_bfrops_base_unpack_ndstats(pmix_pointer_array_t *regtypes, pm
     int32_t i, m, n;
     int ret;
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_NODE_STATS != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     n = *num_vals;
     for (i = 0; i < n; i++) {
@@ -2361,12 +2228,7 @@ pmix_status_t pmix_bfrops_base_unpack_dbuf(pmix_pointer_array_t *regtypes, pmix_
     int32_t i, m, n;
     pmix_status_t ret;
 
-    if (NULL == regtypes) {
-        return PMIX_ERR_BAD_PARAM;
-    }
-    if (PMIX_DATA_BUFFER != type) {
-        return PMIX_ERR_BAD_PARAM;
-    }
+    PMIX_HIDE_UNUSED_PARAMS(type);
 
     n = *num_vals;
     for (i = 0; i < n; ++i) {
@@ -2387,3 +2249,63 @@ pmix_status_t pmix_bfrops_base_unpack_dbuf(pmix_pointer_array_t *regtypes, pmix_
     }
     return PMIX_SUCCESS;
 }
+
+pmix_status_t pmix_bfrops_base_unpack_smed(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                           void *dest, int32_t *num_vals, pmix_data_type_t type)
+{
+    pmix_status_t ret;
+
+    pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
+                        "pmix_bfrop_unpack: %d storage medium", *num_vals);
+
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+    PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT64, regtypes);
+
+    return ret;
+}
+
+pmix_status_t pmix_bfrops_base_unpack_sacc(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                           void *dest, int32_t *num_vals, pmix_data_type_t type)
+{
+    pmix_status_t ret;
+
+    pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
+                        "pmix_bfrop_unpack: %d storage access", *num_vals);
+
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+    PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT64, regtypes);
+
+    return ret;
+}
+
+pmix_status_t pmix_bfrops_base_unpack_spers(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                            void *dest, int32_t *num_vals, pmix_data_type_t type)
+{
+    pmix_status_t ret;
+
+    pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
+                        "pmix_bfrop_unpack: %d storage persistence", *num_vals);
+
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+    PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT64, regtypes);
+
+    return ret;
+}
+
+pmix_status_t pmix_bfrops_base_unpack_satyp(pmix_pointer_array_t *regtypes, pmix_buffer_t *buffer,
+                                            void *dest, int32_t *num_vals, pmix_data_type_t type)
+{
+    pmix_status_t ret;
+
+    pmix_output_verbose(20, pmix_bfrops_base_framework.framework_output,
+                        "pmix_bfrop_unpack: %d storage access type", *num_vals);
+
+    PMIX_HIDE_UNUSED_PARAMS(type);
+
+    PMIX_BFROPS_UNPACK_TYPE(ret, buffer, dest, num_vals, PMIX_UINT16, regtypes);
+
+    return ret;
+}
