@@ -16,7 +16,7 @@
  * Copyright (c) 2016-2019 Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -33,15 +33,15 @@
 #include "bfrop_pmix20.h"
 #include "internal.h"
 #include "src/mca/bfrops/base/base.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/output.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_output.h"
 
 pmix_status_t pmix20_bfrop_pack(pmix_buffer_t *buffer, const void *src, int32_t num_vals,
                                 pmix_data_type_t type)
 {
     pmix_status_t rc;
-    pmix_pointer_array_t *regtypes = &mca_bfrops_v20_component.types;
+    pmix_pointer_array_t *regtypes = &pmix_mca_bfrops_v20_component.types;
 
     /* check for error */
     if (NULL == buffer) {
@@ -94,7 +94,7 @@ pmix_status_t pmix20_bfrop_pack_buffer(pmix_pointer_array_t *regtypes, pmix_buff
 
     if (NULL
         == (info = (pmix_bfrop_type_info_t *)
-                pmix_pointer_array_get_item(&mca_bfrops_v20_component.types, v20type))) {
+                pmix_pointer_array_get_item(&pmix_mca_bfrops_v20_component.types, v20type))) {
         return PMIX_ERR_PACK_FAILURE;
     }
 
