@@ -8,7 +8,7 @@
  * Copyright (c) 2015      Los Alamos National Security, LLC. All rights
  *                         reserved.
  * Copyright (c) 2019-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -16,17 +16,17 @@
  * $HEADER$
  */
 
-#include "pmix_config.h"
+#include "src/include/pmix_config.h"
 
 #ifdef HAVE_UNISTD_H
 #    include "unistd.h"
 #endif
 
-#include "include/pmix_common.h"
-#include "src/mca/base/base.h"
+#include "pmix_common.h"
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/mca.h"
 #include "src/mca/pcompress/base/base.h"
-#include "src/util/output.h"
+#include "src/util/pmix_output.h"
 
 int pmix_compress_base_select(void)
 {
