@@ -4,7 +4,7 @@
  * Copyright (c) 2015      Los Alamos National Security, LLC. All rights
  *                         reserved.
  * Copyright (c) 2020      Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -14,9 +14,9 @@
 
 #include "src/include/pmix_config.h"
 
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 #include "src/mca/pdl/pdl.h"
-#include "src/util/argv.h"
+#include "src/util/pmix_argv.h"
 
 #include "pdl_pdlopen.h"
 
@@ -39,7 +39,7 @@ static int pdlopen_component_query(pmix_mca_base_module_t **module, int *priorit
  * and pointers to our public functions in it
  */
 
-pmix_pdl_pdlopen_component_t mca_pdl_pdlopen_component = {
+pmix_pdl_pdlopen_component_t pmix_mca_pdl_pdlopen_component = {
 
     /* Fill in the mca_pdl_base_component_t */
     .base = {
@@ -63,7 +63,8 @@ pmix_pdl_pdlopen_component_t mca_pdl_pdlopen_component = {
 
         .base_data = {
             /* The component is checkpoint ready */
-            PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT
+            PMIX_MCA_BASE_METADATA_PARAM_CHECKPOINT,
+            .reserved = {0}
         },
 
         /* The pdl framework members */
@@ -75,17 +76,16 @@ static int pdlopen_component_register(void)
 {
     int ret;
 
-    mca_pdl_pdlopen_component.filename_suffixes_mca_storage = ".so,.dylib,.dll,.sl";
-    ret = pmix_mca_base_component_var_register(
-        &mca_pdl_pdlopen_component.base.base_version, "filename_suffixes",
-        "Comma-delimited list of filename suffixes that the pdlopen component will try",
-        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_SETTABLE, PMIX_INFO_LVL_5,
-        PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &mca_pdl_pdlopen_component.filename_suffixes_mca_storage);
+    pmix_mca_pdl_pdlopen_component.filename_suffixes_mca_storage = ".so,.dylib,.dll,.sl";
+    ret = pmix_mca_base_component_var_register(&pmix_mca_pdl_pdlopen_component.base.base_version, "filename_suffixes",
+                                               "Comma-delimited list of filename suffixes that the pdlopen component will try",
+                                               PMIX_MCA_BASE_VAR_TYPE_STRING,
+                                               &pmix_mca_pdl_pdlopen_component.filename_suffixes_mca_storage);
     if (ret < 0) {
         return ret;
     }
-    mca_pdl_pdlopen_component.filename_suffixes
-        = pmix_argv_split(mca_pdl_pdlopen_component.filename_suffixes_mca_storage, ',');
+    pmix_mca_pdl_pdlopen_component.filename_suffixes
+        = pmix_argv_split(pmix_mca_pdl_pdlopen_component.filename_suffixes_mca_storage, ',');
 
     return PMIX_SUCCESS;
 }
@@ -97,9 +97,9 @@ static int pdlopen_component_open(void)
 
 static int pdlopen_component_close(void)
 {
-    if (NULL != mca_pdl_pdlopen_component.filename_suffixes) {
-        pmix_argv_free(mca_pdl_pdlopen_component.filename_suffixes);
-        mca_pdl_pdlopen_component.filename_suffixes = NULL;
+    if (NULL != pmix_mca_pdl_pdlopen_component.filename_suffixes) {
+        pmix_argv_free(pmix_mca_pdl_pdlopen_component.filename_suffixes);
+        pmix_mca_pdl_pdlopen_component.filename_suffixes = NULL;
     }
 
     return PMIX_SUCCESS;
@@ -110,7 +110,7 @@ static int pdlopen_component_query(pmix_mca_base_module_t **module, int *priorit
     /* The priority value is somewhat meaningless here; by
        pmix/mca/pdl/configure.m4, there's at most one component
        available. */
-    *priority = mca_pdl_pdlopen_component.base.priority;
+    *priority = pmix_mca_pdl_pdlopen_component.base.priority;
     *module = &pmix_pdl_pdlopen_module.super;
 
     return PMIX_SUCCESS;
