@@ -13,7 +13,7 @@
  * Copyright (c) 2015      Los Alamos National Security, LLC. All rights
  *                         reserved.
  * Copyright (c) 2017-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -27,8 +27,8 @@
  * entire components just to query their version and parameters.
  */
 
-#include "pmix_config.h"
-#include "include/pmix_common.h"
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
@@ -36,7 +36,7 @@
 #endif
 #include <ctype.h>
 
-#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/mca.h"
 
 #include "src/mca/pfexec/linux/pfexec_linux.h"
@@ -51,7 +51,7 @@ static pmix_status_t component_query(pmix_mca_base_module_t **module, int *prior
  * and pointers to our public functions in it
  */
 
-pmix_pfexec_base_component_t mca_pfexec_linux_component = {
+pmix_pfexec_base_component_t pmix_mca_pfexec_linux_component = {
     /* First, the mca_component_t struct containing meta information
     about the component itself */
     .version = {
