@@ -5,7 +5,7 @@
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -13,8 +13,8 @@
  * $HEADER$
  */
 
-#include "pmix_config.h"
-#include "include/pmix_common.h"
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 #include <string.h>
 #ifdef HAVE_UNISTD_H
@@ -51,15 +51,15 @@
 
 #include "src/mca/pif/base/base.h"
 #include "src/mca/pif/pif.h"
-#include "src/util/output.h"
-#include "src/util/pif.h"
+#include "src/util/pmix_output.h"
+#include "src/util/pmix_if.h"
 
 static int if_posix_open(void);
 
 /* Supports all flavors of posix except those
  * BSD-flavors supported elsewhere
  */
-pmix_pif_base_component_t mca_pif_posix_ipv4_component = {
+pmix_pif_base_component_t pmix_mca_pif_posix_ipv4_component = {
     /* First, the mca_component_t struct containing meta information
        about the component itself */
     .base = {
