@@ -1,7 +1,7 @@
 /* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
  * Copyright (c) 2018-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -12,8 +12,8 @@
 /*
  * includes
  */
-#include "pmix_config.h"
-#include "include/pmix_common.h"
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 #include "plog_default.h"
 
@@ -22,7 +22,7 @@ static pmix_status_t component_query(pmix_mca_base_module_t **module, int *prior
 /*
  * Struct of function pointers that need to be initialized
  */
-pmix_plog_base_component_t mca_plog_default_component = {
+pmix_plog_base_component_t pmix_mca_plog_default_component = {
     .base = {
         PMIX_PLOG_BASE_VERSION_1_0_0,
 
