@@ -2,7 +2,7 @@
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
  *
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -30,7 +30,7 @@
 #endif
 #include <time.h>
 
-#include "include/pmix.h"
+#include "pmix.h"
 
 #include "src/class/pmix_list.h"
 #include "src/class/pmix_pointer_array.h"
@@ -39,14 +39,14 @@
 #include "src/mca/base/pmix_mca_base_var.h"
 #include "src/mca/base/pmix_mca_base_vari.h"
 #include "src/mca/preg/preg.h"
-#include "src/util/alfg.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/name_fns.h"
-#include "src/util/os_path.h"
-#include "src/util/output.h"
+#include "src/util/pmix_alfg.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_name_fns.h"
+#include "src/util/pmix_os_path.h"
+#include "src/util/pmix_output.h"
 #include "src/util/pmix_environ.h"
-#include "src/util/printf.h"
+#include "src/util/pmix_printf.h"
 
 #include "pmdl_ompi.h"
 #include "src/mca/pmdl/base/base.h"
@@ -299,17 +299,17 @@ harvest:
     }
 
     /* harvest our local envars */
-    if (NULL != mca_pmdl_ompi_component.include) {
+    if (NULL != pmix_mca_pmdl_ompi_component.include) {
         pmix_output_verbose(2, pmix_pmdl_base_framework.framework_output,
                             "pmdl: ompi harvesting envars %s excluding %s",
-                            (NULL == mca_pmdl_ompi_component.incparms)
+                            (NULL == pmix_mca_pmdl_ompi_component.incparms)
                             ? "NONE"
-                            : mca_pmdl_ompi_component.incparms,
-                            (NULL == mca_pmdl_ompi_component.excparms)
+                            : pmix_mca_pmdl_ompi_component.incparms,
+                            (NULL == pmix_mca_pmdl_ompi_component.excparms)
                             ? "NONE"
-                            : mca_pmdl_ompi_component.excparms);
-        rc = pmix_util_harvest_envars(mca_pmdl_ompi_component.include,
-                                      mca_pmdl_ompi_component.exclude, ilist);
+                            : pmix_mca_pmdl_ompi_component.excparms);
+        rc = pmix_util_harvest_envars(pmix_mca_pmdl_ompi_component.include,
+                                      pmix_mca_pmdl_ompi_component.exclude, ilist);
         if (PMIX_SUCCESS != rc) {
             return rc;
         }
