@@ -13,7 +13,7 @@
  * Copyright (c) 2015      Los Alamos National Security, LLC. All rights
  *                         reserved.
  * Copyright (c) 2016-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -23,11 +23,11 @@
  */
 
 #include "src/include/pmix_config.h"
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 
 #include "pmdl_ompi.h"
 #include "src/mca/pmdl/pmdl.h"
-#include "src/util/argv.h"
+#include "src/util/pmix_argv.h"
 
 static pmix_status_t component_register(void);
 static pmix_status_t component_query(pmix_mca_base_module_t **module, int *priority);
@@ -36,7 +36,7 @@ static pmix_status_t component_query(pmix_mca_base_module_t **module, int *prior
  * Instantiate the public struct with all of our public information
  * and pointers to our public functions in it
  */
-pmix_pmdl_ompi_component_t mca_pmdl_ompi_component = {
+pmix_pmdl_ompi_component_t pmix_mca_pmdl_ompi_component = {
     .super = {
         .base = {
             PMIX_PMDL_BASE_VERSION_1_0_0,
@@ -64,26 +64,26 @@ pmix_pmdl_ompi_component_t mca_pmdl_ompi_component = {
 
 static pmix_status_t component_register(void)
 {
-    pmix_mca_base_component_t *component = &mca_pmdl_ompi_component.super.base;
+    pmix_mca_base_component_t *component = &pmix_mca_pmdl_ompi_component.super.base;
 
-    mca_pmdl_ompi_component.incparms = "OMPI_*";
-    (void) pmix_mca_base_component_var_register(
-        component, "include_envars",
-        "Comma-delimited list of envars to harvest (\'*\' and \'?\' supported)",
-        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
-        PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &mca_pmdl_ompi_component.incparms);
-    if (NULL != mca_pmdl_ompi_component.incparms) {
-        mca_pmdl_ompi_component.include = pmix_argv_split(mca_pmdl_ompi_component.incparms, ',');
+    pmix_mca_pmdl_ompi_component.incparms = "OMPI_*";
+    (void) pmix_mca_base_component_var_register(component,
+                                                "include_envars",
+                                                "Comma-delimited list of envars to harvest (\'*\' and \'?\' supported)",
+                                                PMIX_MCA_BASE_VAR_TYPE_STRING,
+                                                &pmix_mca_pmdl_ompi_component.incparms);
+    if (NULL != pmix_mca_pmdl_ompi_component.incparms) {
+        pmix_mca_pmdl_ompi_component.include = pmix_argv_split(pmix_mca_pmdl_ompi_component.incparms, ',');
     }
 
-    mca_pmdl_ompi_component.excparms = NULL;
-    (void) pmix_mca_base_component_var_register(
-        component, "exclude_envars",
-        "Comma-delimited list of envars to exclude (\'*\' and \'?\' supported)",
-        PMIX_MCA_BASE_VAR_TYPE_STRING, NULL, 0, PMIX_MCA_BASE_VAR_FLAG_NONE, PMIX_INFO_LVL_2,
-        PMIX_MCA_BASE_VAR_SCOPE_LOCAL, &mca_pmdl_ompi_component.excparms);
-    if (NULL != mca_pmdl_ompi_component.excparms) {
-        mca_pmdl_ompi_component.exclude = pmix_argv_split(mca_pmdl_ompi_component.excparms, ',');
+    pmix_mca_pmdl_ompi_component.excparms = NULL;
+    (void) pmix_mca_base_component_var_register(component,
+                                                "exclude_envars",
+                                                "Comma-delimited list of envars to exclude (\'*\' and \'?\' supported)",
+                                                PMIX_MCA_BASE_VAR_TYPE_STRING,
+                                                &pmix_mca_pmdl_ompi_component.excparms);
+    if (NULL != pmix_mca_pmdl_ompi_component.excparms) {
+        pmix_mca_pmdl_ompi_component.exclude = pmix_argv_split(pmix_mca_pmdl_ompi_component.excparms, ',');
     }
 
     return PMIX_SUCCESS;
