@@ -5,7 +5,7 @@
  * Copyright (c) 2015-2018 Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2018-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -28,7 +28,7 @@
 #define PMIX_PMDL_H
 
 #include "src/include/pmix_config.h"
-#include "include/pmix.h"
+#include "pmix.h"
 
 #include "src/class/pmix_list.h"
 #include "src/include/pmix_globals.h"
