@@ -85,6 +85,7 @@ PMIX_EXPORT PMIX_CLASS_DECLARATION(pmix_pnet_fabric_t);
 struct pmix_pnet_globals_t {
     pmix_list_t actives;
     pmix_list_t fabrics;
+    pmix_list_t nspaces;
     bool selected;
 };
 typedef struct pmix_pnet_globals_t pmix_pnet_globals_t;
@@ -99,11 +100,10 @@ PMIX_EXPORT pmix_status_t pmix_pnet_base_setup_fork(const pmix_proc_t *peer, cha
 PMIX_EXPORT void pmix_pnet_base_child_finalized(pmix_proc_t *peer);
 PMIX_EXPORT void pmix_pnet_base_local_app_finalized(pmix_namespace_t *nptr);
 PMIX_EXPORT void pmix_pnet_base_deregister_nspace(char *nspace);
-PMIX_EXPORT void pmix_pnet_base_collect_inventory(pmix_info_t directives[], size_t ndirs,
-                                                  pmix_inventory_cbfunc_t cbfunc, void *cbdata);
-PMIX_EXPORT void pmix_pnet_base_deliver_inventory(pmix_info_t info[], size_t ninfo,
-                                                  pmix_info_t directives[], size_t ndirs,
-                                                  pmix_op_cbfunc_t cbfunc, void *cbdata);
+PMIX_EXPORT pmix_status_t pmix_pnet_base_collect_inventory(pmix_info_t directives[], size_t ndirs,
+                                                           pmix_list_t *inventory);
+PMIX_EXPORT pmix_status_t pmix_pnet_base_deliver_inventory(pmix_info_t info[], size_t ninfo,
+                                                           pmix_info_t directives[], size_t ndirs);
 PMIX_EXPORT pmix_status_t pmix_pnet_base_harvest_envars(char **incvars, char **excvars,
                                                         pmix_list_t *ilist);
 
