@@ -9,7 +9,10 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2016-2017 Intel, Inc. All rights reserved.
+ * Copyright (c) 2016-2020 Intel, Inc.  All rights reserved.
+ * Copyright (c) 2020      Research Organization for Information Science
+ *                         and Technology (RIST).  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -17,20 +20,18 @@
  * $HEADER$
  */
 
-#include <src/include/pmix_config.h>
-#include <pmix_common.h>
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 #include <string.h>
 
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/mca.h"
-#include "src/mca/base/base.h"
-#include "src/util/error.h"
-#include "src/util/show_help.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_show_help.h"
 
 #include "src/mca/psec/base/base.h"
 
-static bool selected = false;
-
 /* Function for selecting a prioritized list of components
  * from all those that are available. */
 int pmix_psec_base_select(void)
@@ -43,24 +44,27 @@ int pmix_psec_base_select(void)
     int rc, priority;
     bool inserted;
 
-    if (selected) {
+    if (pmix_psec_globals.selected) {
         /* ensure we don't do this twice */
         return PMIX_SUCCESS;
     }
-    selected = true;
+    pmix_psec_globals.selected = true;
 
     /* Query all available components and ask if they have a module */
-    PMIX_LIST_FOREACH(cli, &pmix_psec_base_framework.framework_components, pmix_mca_base_component_list_item_t) {
+    PMIX_LIST_FOREACH (cli, &pmix_psec_base_framework.framework_components,
+                       pmix_mca_base_component_list_item_t) {
         component = (pmix_mca_base_component_t *) cli->cli_component;
 
         pmix_output_verbose(5, pmix_psec_base_framework.framework_output,
-                            "mca:psec:select: checking available component %s", component->pmix_mca_component_name);
+                            "mca:psec:select: checking available component %s",
+                            component->pmix_mca_component_name);
 
         /* If there's no query function, skip it */
         if (NULL == component->pmix_mca_query_component) {
-            pmix_output_verbose(5, pmix_psec_base_framework.framework_output,
-                                "mca:psec:select: Skipping component [%s]. It does not implement a query function",
-                                component->pmix_mca_component_name );
+            pmix_output_verbose(
+                5, pmix_psec_base_framework.framework_output,
+                "mca:psec:select: Skipping component [%s]. It does not implement a query function",
+                component->pmix_mca_component_name);
             continue;
         }
 
@@ -72,12 +76,13 @@ int pmix_psec_base_select(void)
 
         /* If no module was returned, then skip component */
         if (PMIX_SUCCESS != rc || NULL == module) {
-            pmix_output_verbose(5, pmix_psec_base_framework.framework_output,
-                                "mca:psec:select: Skipping component [%s]. Query failed to return a module",
-                                component->pmix_mca_component_name);
+            pmix_output_verbose(
+                5, pmix_psec_base_framework.framework_output,
+                "mca:psec:select: Skipping component [%s]. Query failed to return a module",
+                component->pmix_mca_component_name);
             continue;
         }
-        nmodule = (pmix_psec_module_t*) module;
+        nmodule = (pmix_psec_module_t *) module;
 
         /* give the module a chance to init */
         if (NULL != nmodule->init && PMIX_SUCCESS != nmodule->init()) {
@@ -93,14 +98,14 @@ int pmix_psec_base_select(void)
         newmodule = PMIX_NEW(pmix_psec_base_active_module_t);
         newmodule->pri = priority;
         newmodule->module = nmodule;
-        newmodule->component = (pmix_psec_base_component_t*)cli->cli_component;
+        newmodule->component = (pmix_psec_base_component_t *) cli->cli_component;
 
         /* maintain priority order */
         inserted = false;
-        PMIX_LIST_FOREACH(mod, &pmix_psec_globals.actives, pmix_psec_base_active_module_t) {
+        PMIX_LIST_FOREACH (mod, &pmix_psec_globals.actives, pmix_psec_base_active_module_t) {
             if (priority > mod->pri) {
-                pmix_list_insert_pos(&pmix_psec_globals.actives,
-                                     (pmix_list_item_t*)mod, &newmodule->super);
+                pmix_list_insert_pos(&pmix_psec_globals.actives, (pmix_list_item_t *) mod,
+                                     &newmodule->super);
                 inserted = true;
                 break;
             }
@@ -120,10 +125,12 @@ int pmix_psec_base_select(void)
     if (4 < pmix_output_get_verbosity(pmix_psec_base_framework.framework_output)) {
         pmix_output(0, "Final psec priorities");
         /* show the prioritized list */
-        PMIX_LIST_FOREACH(mod, &pmix_psec_globals.actives, pmix_psec_base_active_module_t) {
-            pmix_output(0, "\tpsec: %s Priority: %d", mod->component->base.pmix_mca_component_name, mod->pri);
+        PMIX_LIST_FOREACH (mod, &pmix_psec_globals.actives, pmix_psec_base_active_module_t) {
+            pmix_output(0, "\tpsec: %s Priority: %d", mod->component->base.pmix_mca_component_name,
+                        mod->pri);
         }
     }
 
-    return PMIX_SUCCESS;;
+    return PMIX_SUCCESS;
+    ;
 }
