@@ -4,7 +4,7 @@
  * Copyright (c) 2017      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  *
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -14,13 +14,13 @@
 
 #include "src/include/pmix_config.h"
 
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 
 #include "src/include/pmix_globals.h"
 #include "src/include/pmix_socket_errno.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/output.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_output.h"
 
 #include <unistd.h>
 #ifdef HAVE_SYS_TYPES_H
@@ -60,6 +60,8 @@ static pmix_status_t create_cred(struct pmix_peer_t *peer, const pmix_info_t dir
                                  size_t ndirs, pmix_info_t **info, size_t *ninfo,
                                  pmix_byte_object_t *cred)
 {
+    PMIX_HIDE_UNUSED_PARAMS(peer, directives, ndirs, info, ninfo);
+
     /* ensure initialization */
     PMIX_BYTE_OBJECT_CONSTRUCT(cred);
 
@@ -76,6 +78,8 @@ static pmix_status_t validate_cred(struct pmix_peer_t *peer, const pmix_info_t d
 
     pmix_output_verbose(2, pmix_globals.debug_output, "psec: none always reports valid");
 
+    PMIX_HIDE_UNUSED_PARAMS(peer, cred);
+
     /* if we are responding to a local request to validate a credential,
      * then see if they specified a mechanism */
     if (NULL != directives && 0 < ndirs) {
