@@ -2,7 +2,7 @@
 /*
  * Copyright (c) 2019      IBM Corporation.  All rights reserved.
  * Copyright (c) 2020      Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -11,7 +11,7 @@
  */
 
 #include "src/include/pmix_config.h"
-#include "include/pmix_common.h"
+#include "pmix_common.h"
 
 #include "psquash_flex128.h"
 #include "src/mca/base/pmix_mca_base_var.h"
@@ -25,7 +25,7 @@ static pmix_status_t component_query(pmix_mca_base_module_t **module, int *prior
  * Instantiate the public struct with all of our public information
  * and pointers to our public functions in it
  */
-pmix_psquash_base_component_t mca_psquash_flex128_component = {
+pmix_psquash_base_component_t pmix_mca_psquash_flex128_component = {
     .base = {
         PMIX_PSQUASH_BASE_VERSION_1_0_0,
 
