@@ -15,7 +15,7 @@
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  *
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -23,8 +23,8 @@
  * $HEADER$
  */
 
-#include "pmix_config.h"
-#include "include/pmix_common.h"
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 /* This component will only be compiled on Linux, where we are
    guaranteed to have <unistd.h> and friends */
@@ -44,8 +44,8 @@
 
 #include "pstat_linux.h"
 #include "src/include/pmix_globals.h"
-#include "src/util/argv.h"
-#include "src/util/printf.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_printf.h"
 
 /*
  * API functions
@@ -574,7 +574,7 @@ static void local_getfields(char *dptr, char ***fields)
     }
 
     /* working from this point, find the end of each
-     * alpha-numeric field and store it on the stack.
+     * alphanumeric field and store it on the stack.
      * Then shift across the white space to the start
      * of the next one
      */
