@@ -10,7 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -42,7 +42,7 @@
 #ifdef HAVE_DIRENT_H
 #    include <dirent.h>
 #endif
-#ifdef HAVE_SYS_SYSCTL_H
+#if PMIX_HAVE_APPLE && defined(HAVE_SYS_SYSCTL_H)
 #    include <sys/sysctl.h>
 #endif
 
@@ -52,13 +52,13 @@
 #include "src/mca/bfrops/base/base.h"
 #include "src/mca/gds/gds.h"
 #include "src/server/pmix_server_ops.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/getid.h"
-#include "src/util/os_path.h"
-#include "src/util/printf.h"
-#include "src/util/show_help.h"
-#include "src/util/strnlen.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_getid.h"
+#include "src/util/pmix_os_path.h"
+#include "src/util/pmix_printf.h"
+#include "src/util/pmix_show_help.h"
+#include "src/util/pmix_strnlen.h"
 
 #include "src/mca/ptl/base/base.h"
 
@@ -174,7 +174,7 @@ pmix_status_t pmix_ptl_base_recv_blocking(int sd, char *data, size_t size)
                    in that case is a RST packet, which receive
                    will turn into a connection reset by peer
                    errno.  In that case, leave the socket in
-                   CONNECT_ACK and propogate the error up to
+                   CONNECT_ACK and propagate the error up to
                    recv_connect_ack, who will try to establish the
                    connection again */
                 pmix_output_verbose(8, pmix_ptl_base_framework.framework_output,
