@@ -10,7 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -38,10 +38,10 @@
 #include "src/mca/bfrops/base/base.h"
 #include "src/mca/gds/base/base.h"
 #include "src/server/pmix_server_ops.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/getid.h"
-#include "src/util/strnlen.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_getid.h"
+#include "src/util/pmix_strnlen.h"
 
 #include "src/mca/ptl/base/base.h"
 #include "src/mca/ptl/base/ptl_base_handshake.h"
@@ -94,9 +94,10 @@ void pmix_ptl_base_connection_handler(int sd, short args, void *cbdata)
     if (PMIX_MAX_CRED_SIZE < hdr.nbytes) {
         goto error;
     }
-    if (NULL == (msg = (char *) malloc(hdr.nbytes))) {
+    if (NULL == (msg = (char *) malloc(hdr.nbytes+1))) {
         goto error;
     }
+    memset(msg, 0, hdr.nbytes + 1);  // ensure NULL termination of result
     if (PMIX_SUCCESS != pmix_ptl_base_recv_blocking(pnd->sd, msg, hdr.nbytes)) {
         /* unable to complete the recv */
         pmix_output_verbose(2, pmix_ptl_base_framework.framework_output,
