@@ -26,9 +26,9 @@
 #include "src/include/pmix_globals.h"
 #include "src/runtime/pmix_progress_threads.h"
 #include "src/runtime/pmix_rte.h"
-#include "src/threads/threads.h"
-#include "src/util/error.h"
-#include "src/util/fd.h"
+#include "src/threads/pmix_threads.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_fd.h"
 
 /* create a tracking object for progress threads */
 typedef struct {
@@ -296,6 +296,7 @@ static int start_progress_engine(pmix_progress_tracker_t *trk)
         } else {
             rc = PMIX_SUCCESS;
         }
+        pmix_argv_free(ranges);
     }
 #endif
     return rc;
