@@ -8,7 +8,7 @@
  * Copyright (c) 2016      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -49,10 +49,10 @@
 #include "src/mca/bfrops/bfrops.h"
 #include "src/mca/gds/gds.h"
 #include "src/mca/ptl/base/base.h"
-#include "src/util/argv.h"
-#include "src/util/error.h"
-#include "src/util/name_fns.h"
-#include "src/util/output.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_name_fns.h"
+#include "src/util/pmix_output.h"
 #include "src/util/pmix_environ.h"
 
 #include "pmix_server_ops.h"
@@ -89,7 +89,8 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
 static pmix_status_t create_local_tracker(char nspace[], pmix_rank_t rank, pmix_info_t info[],
                                           size_t ninfo, pmix_modex_cbfunc_t cbfunc, void *cbdata,
                                           pmix_dmdx_local_t **lcd, pmix_dmdx_request_t **rq);
-static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd, pmix_buffer_t *pbkt);
+static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd,
+                                  char *key, pmix_buffer_t *pbkt);
 static void get_timeout(int sd, short args, void *cbdata);
 
 /* declare a function whose sole purpose is to
@@ -285,12 +286,12 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
         goto request;
     }
 
-    /* the target nspace is known, so we can process the request.
-     * if the rank is wildcard, then they are asking for the job-level
-     * info for this nspace - provide it */
+    /* the target nspace is known, so we can process the request */
     if (PMIX_RANK_WILDCARD == rank) {
         PMIX_CONSTRUCT(&pbkt, pmix_buffer_t);
-        rc = get_job_data(nptr->nspace, cd, &pbkt);
+        /* they are asking for the job-level info for (or at least a
+         * reserved key from) this nspace */
+        rc = get_job_data(nptr->nspace, cd, key, &pbkt);
         if (PMIX_SUCCESS != rc) {
             PMIX_DESTRUCT(&pbkt);
             return rc;
@@ -405,7 +406,7 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
          * request. In this case, we create a local tracker for
          * possibly existing keys that are added with the completed
          * commit request. Thus, the get request will be pended in
-         * tracker and will be deffered. This scenario is possible
+         * tracker and will be deferred. This scenario is possible
          * when the non-fence commit-get scheme is used and when
          * the peer GDS component is `dstore`.
          * Checking the peer storage for local keys to avoid creating
@@ -449,7 +450,7 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
         /* we did find it, so go ahead and collect the payload */
     } else if (PMIX_PEER_IS_EARLIER(pmix_client_globals.myserver, 4, 0, 0)) {
         PMIX_CONSTRUCT(&pbkt, pmix_buffer_t);
-        rc = get_job_data(nspace, cd, &pbkt);
+        rc = get_job_data(nspace, cd, key, &pbkt);
         if (PMIX_SUCCESS != rc) {
             PMIX_DESTRUCT(&pbkt);
             return rc;
@@ -662,7 +663,10 @@ void pmix_pending_nspace_requests(pmix_namespace_t *nptr)
     }
 }
 
-static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd, pmix_buffer_t *pbkt)
+static pmix_status_t get_job_data(char *nspace,
+                                  pmix_server_caddy_t *cd,
+                                  char *key,
+                                  pmix_buffer_t *pbkt)
 {
     pmix_status_t rc;
     pmix_buffer_t pkt;
@@ -676,6 +680,7 @@ static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd, pmix_bu
      * of returning a copy of the data, or a pointer to
      * local storage */
     cb.proc = &proc;
+    cb.key = key;
     cb.scope = PMIX_INTERNAL;
     cb.copy = false;
     cb.info = cd->info;
@@ -690,7 +695,6 @@ static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd, pmix_bu
         if (rc != PMIX_SUCCESS) {
             PMIX_ERROR_LOG(rc);
             PMIX_DESTRUCT(&pkt);
-            PMIX_DESTRUCT(&pbkt);
             PMIX_DESTRUCT(&cb);
             return rc;
         }
@@ -733,15 +737,20 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
 {
     pmix_status_t rc;
     bool found = false;
+    bool used_mypeer = true;
     pmix_buffer_t pbkt, pkt;
     pmix_proc_t proc;
     pmix_cb_t cb;
     pmix_byte_object_t bo;
     char *data = NULL;
     size_t sz = 0;
+    pmix_rank_info_t *rinfo;
+    pmix_peer_t *peer;
 
-    pmix_output_verbose(2, pmix_server_globals.get_output, "%s:%d SATISFY REQUEST CALLED FOR %s:%d",
-                        pmix_globals.myid.nspace, pmix_globals.myid.rank, nptr->nspace, rank);
+    pmix_output_verbose(2, pmix_server_globals.get_output,
+                        "%s:%d SATISFY REQUEST CALLED FOR %s:%d ON SCOPE %s",
+                        pmix_globals.myid.nspace, pmix_globals.myid.rank,
+                        nptr->nspace, rank, PMIx_Scope_string(scope));
 
     PMIX_CONSTRUCT(&pbkt, pmix_buffer_t);
     PMIX_LOAD_NSPACE(proc.nspace, nptr->nspace);
@@ -749,7 +758,7 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
     /* if the rank is WILDCARD or the target is in an nspace different
      * from the requester, include a copy of the job-level data */
     if (PMIX_RANK_WILDCARD == rank || diffnspace) {
-        rc = get_job_data(nptr->nspace, cd, &pbkt);
+        rc = get_job_data(nptr->nspace, cd, NULL, &pbkt);
         if (PMIX_SUCCESS != rc) {
             PMIX_DESTRUCT(&pbkt);
             return rc;
@@ -768,13 +777,29 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
     cb.info = cd->info;
     cb.ninfo = cd->ninfo;
     PMIX_GDS_FETCH_KV(rc, pmix_globals.mypeer, &cb);
+    /* if we didn't find it on my peer, it could have
+     * been stored on their peer - so check there */
+    if (PMIX_SUCCESS != rc) {
+        /* all procs in a given nspace must use
+         * the same GDS component */
+        peer = NULL;
+        rinfo = (pmix_rank_info_t*)pmix_list_get_first(&nptr->ranks);
+        while (NULL == peer && NULL != rinfo) {
+            peer = (pmix_peer_t*)pmix_pointer_array_get_item(&pmix_server_globals.clients, rinfo->peerid);
+            rinfo = (pmix_rank_info_t*)pmix_list_get_next(&rinfo->super);
+        }
+        if (NULL != peer) {
+            PMIX_GDS_FETCH_KV(rc, peer, &cb);
+            used_mypeer = false;
+        }
+    }
     cb.info = NULL;
     cb.ninfo = 0;
     if (PMIX_SUCCESS == rc) {
         found = true;
         PMIX_CONSTRUCT(&pkt, pmix_buffer_t);
         /* assemble the provided data into a byte object */
-        if (PMIX_RANK_UNDEF == rank || diffnspace) {
+        if (PMIX_RANK_UNDEF == rank || diffnspace || used_mypeer) {
             PMIX_GDS_ASSEMB_KVS_REQ(rc, pmix_globals.mypeer, &proc, &cb.kvs, &pkt, cd);
         } else {
             PMIX_GDS_ASSEMB_KVS_REQ(rc, cd->peer, &proc, &cb.kvs, &pkt, cd);
@@ -843,7 +868,10 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
 }
 
 /* Resolve pending requests to this namespace/rank */
-pmix_status_t pmix_pending_resolve(pmix_namespace_t *nptr, pmix_rank_t rank, pmix_status_t status,
+pmix_status_t pmix_pending_resolve(pmix_namespace_t *nptr,
+                                   pmix_rank_t rank,
+                                   pmix_status_t status,
+                                   pmix_scope_t scope,
                                    pmix_dmdx_local_t *lcd)
 {
     pmix_dmdx_local_t *cd, *ptr;
@@ -893,8 +921,8 @@ pmix_status_t pmix_pending_resolve(pmix_namespace_t *nptr, pmix_rank_t rank, pmi
         PMIX_LIST_FOREACH (req, &ptr->loc_reqs, pmix_dmdx_request_t) {
             pmix_status_t rc;
             bool diffnspace = !PMIX_CHECK_NSPACE(nptr->nspace, req->lcd->proc.nspace);
-            rc = _satisfy_request(nptr, rank, &scd, diffnspace, PMIX_REMOTE, req->cbfunc,
-                                  req->cbdata);
+            rc = _satisfy_request(nptr, rank, &scd, diffnspace, scope,
+                                  req->cbfunc, req->cbdata);
             if (PMIX_SUCCESS != rc) {
                 /* if we can't satisfy this particular request (missing key?) */
                 req->cbfunc(rc, NULL, 0, req->cbdata, NULL, NULL);
@@ -927,7 +955,7 @@ static void _process_dmdx_reply(int sd, short args, void *cbdata)
     pmix_dmdx_reply_caddy_t *caddy = (pmix_dmdx_reply_caddy_t *) cbdata;
     pmix_server_caddy_t *cd;
     pmix_peer_t *peer;
-    pmix_rank_info_t *rinfo;
+    pmix_rank_info_t *rinfo, *rptr;
     int32_t cnt;
     pmix_kval_t *kv;
     pmix_namespace_t *ns, *nptr;
@@ -942,8 +970,10 @@ static void _process_dmdx_reply(int sd, short args, void *cbdata)
     PMIX_ACQUIRE_OBJECT(caddy);
     PMIX_HIDE_UNUSED_PARAMS(sd, args);
 
-    pmix_output_verbose(2, pmix_server_globals.get_output, "[%s:%d] process dmdx reply from %s:%u",
-                        __FILE__, __LINE__, caddy->lcd->proc.nspace, caddy->lcd->proc.rank);
+    pmix_output_verbose(2, pmix_server_globals.get_output,
+                        "[%s:%d] process dmdx reply from %s:%u",
+                        __FILE__, __LINE__,
+                        caddy->lcd->proc.nspace, caddy->lcd->proc.rank);
 
     /* find the nspace object for the proc whose data is being received */
     nptr = NULL;
@@ -1009,7 +1039,13 @@ static void _process_dmdx_reply(int sd, short args, void *cbdata)
                 peer = pmix_globals.mypeer;
             } else {
                 /* there must be at least one local proc */
-                rinfo = (pmix_rank_info_t *) pmix_list_get_first(&nm->ns->ranks);
+                rinfo = NULL;
+                PMIX_LIST_FOREACH(rptr, &nm->ns->ranks, pmix_rank_info_t) {
+                    if (0 <= rptr->peerid) {
+                        rinfo = rptr;
+                        break;
+                    }
+                }
                 if (NULL == rinfo) {
                     PMIX_ERROR_LOG(PMIX_ERR_NOT_FOUND);
                     goto complete;
@@ -1089,7 +1125,8 @@ static void _process_dmdx_reply(int sd, short args, void *cbdata)
 
 complete:
     /* always execute the callback to avoid having the client hang */
-    pmix_pending_resolve(nptr, caddy->lcd->proc.rank, caddy->status, caddy->lcd);
+    pmix_pending_resolve(nptr, caddy->lcd->proc.rank,
+                         caddy->status, PMIX_REMOTE, caddy->lcd);
 
     /* now call the release function so the host server
      * knows it can release the data */
