@@ -16,7 +16,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -24,7 +24,7 @@
  * $HEADER$
  */
 
-#include "pmix_config.h"
+#include "src/include/pmix_config.h"
 
 #include <ctype.h>
 #include <stdio.h>
@@ -43,15 +43,15 @@
 
 #include "src/class/pmix_object.h"
 #include "src/class/pmix_pointer_array.h"
-#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/pinstalldirs/base/base.h"
 #include "src/runtime/pmix_rte.h"
-#include "src/util/argv.h"
-#include "src/util/cmd_line.h"
-#include "src/util/error.h"
-#include "src/util/keyval_parse.h"
-#include "src/util/output.h"
-#include "src/util/show_help.h"
+#include "src/util/pmix_argv.h"
+#include "src/util/pmix_cmd_line.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_keyval_parse.h"
+#include "src/util/pmix_output.h"
+#include "src/util/pmix_show_help.h"
 
 #include "pinfo.h"
 #include "support.h"
@@ -60,7 +60,8 @@
  * Public variables
  */
 
-pmix_cmd_line_t *pmix_info_cmd_line = NULL;
+pmix_cli_result_t *pmix_info_cmd_line = NULL;
+pmix_cli_result_t results = PMIX_CLI_RESULT_STATIC_INIT;
 pmix_pointer_array_t pmix_component_map = PMIX_POINTER_ARRAY_STATIC_INIT;
 pmix_pointer_array_t mca_types = PMIX_POINTER_ARRAY_STATIC_INIT;
 
@@ -74,10 +75,16 @@ int main(int argc, char *argv[])
     int i;
     pmix_info_component_map_t *map;
 
+    pmix_info_cmd_line = &results;
+    PMIX_CONSTRUCT(&results, pmix_cli_result_t);
+
     /* protect against problems if someone passes us thru a pipe
      * and then abnormally terminates the pipe early */
     signal(SIGPIPE, SIG_IGN);
 
+    /* init globals */
+    pmix_tool_basename = "pmix_info";
+
     /* initialize the output system */
     if (!pmix_output_init()) {
         return PMIX_ERROR;
@@ -102,7 +109,7 @@ int main(int argc, char *argv[])
     }
 
     /* initialize the help system */
-    pmix_show_help_init();
+    pmix_show_help_init(NULL);
 
     /* keyval lex-based parser */
     if (PMIX_SUCCESS != (ret = pmix_util_keyval_parse_init())) {
@@ -122,14 +129,6 @@ int main(int argc, char *argv[])
         return PMIX_ERROR;
     }
 
-    pmix_info_cmd_line = PMIX_NEW(pmix_cmd_line_t);
-    if (NULL == pmix_info_cmd_line) {
-        ret = errno;
-        pmix_show_help("help-pmix-info.txt", "lib-call-fail", true, "pmix_cmd_line_create",
-                       __FILE__, __LINE__, NULL);
-        exit(ret);
-    }
-
     if (PMIX_SUCCESS != (ret = pmix_info_init(argc, argv))) {
         return ret;
     }
@@ -147,7 +146,7 @@ int main(int argc, char *argv[])
     if (PMIX_SUCCESS != (ret = pmix_info_register_framework_params())) {
         if (PMIX_ERR_BAD_PARAM == ret) {
             /* output what we got */
-            pmix_info_do_params(true, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"));
+            pmix_info_do_params(true);
         }
         exit(1);
     }
@@ -176,7 +175,7 @@ int main(int argc, char *argv[])
     }
     if (want_all || pmix_cmd_line_is_taken(pmix_info_cmd_line, "param")
         || pmix_cmd_line_is_taken(pmix_info_cmd_line, "params")) {
-        pmix_info_do_params(want_all, pmix_cmd_line_is_taken(pmix_info_cmd_line, "internal"));
+        pmix_info_do_params(want_all);
         acted = true;
     }
     if (pmix_cmd_line_is_taken(pmix_info_cmd_line, "type")) {
@@ -199,7 +198,7 @@ int main(int argc, char *argv[])
 
     /* All done */
     pmix_info_close_components();
-    PMIX_RELEASE(pmix_info_cmd_line);
+    PMIX_DESTRUCT(pmix_info_cmd_line);
     PMIX_DESTRUCT(&mca_types);
     for (i = 0; i < pmix_component_map.size; i++) {
         if (NULL
