@@ -18,7 +18,7 @@
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
- * Copyright (c) 2021      Nanook Consulting  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -32,8 +32,8 @@
  *
  */
 
-#include "pmix_config.h"
-#include "include/pmix_common.h"
+#include "src/include/pmix_config.h"
+#include "pmix_common.h"
 
 #include <errno.h>
 #include <stdio.h>
@@ -55,19 +55,19 @@
 #    include <dirent.h>
 #endif /* HAVE_DIRENT_H */
 
-#include "src/mca/base/base.h"
+#include "src/mca/base/pmix_base.h"
 #include "src/mca/pinstalldirs/base/base.h"
 #include "src/runtime/pmix_rte.h"
-#include "src/threads/threads.h"
-#include "src/util/basename.h"
-#include "src/util/cmd_line.h"
-#include "src/util/keyval_parse.h"
-#include "src/util/output.h"
+#include "src/threads/pmix_threads.h"
+#include "src/util/pmix_basename.h"
+#include "src/util/pmix_cmd_line.h"
+#include "src/util/pmix_keyval_parse.h"
+#include "src/util/pmix_output.h"
 #include "src/util/pmix_environ.h"
-#include "src/util/show_help.h"
+#include "src/util/pmix_show_help.h"
 
-#include "include/pmix.h"
-#include "include/pmix_tool.h"
+#include "pmix.h"
+#include "pmix_tool.h"
 #include "src/include/pmix_globals.h"
 
 typedef struct {
@@ -105,44 +105,24 @@ static char *pretty_node_state(pmix_node_state_t state);
 static int parseable_print(pmix_ps_mpirun_info_t *hnpinfo);
 #endif
 
-/*****************************************
- * Global Vars for Command line Arguments
- *****************************************/
-typedef struct {
-    bool help;
-    bool parseable;
-    bool nodes;
-    char *nspace;
-    pid_t pid;
-} pmix_ps_globals_t;
+static struct option ppsoptions[] = {
+    PMIX_OPTION_SHORT_DEFINE(PMIX_CLI_HELP, PMIX_ARG_OPTIONAL, 'h'),
+    PMIX_OPTION_SHORT_DEFINE(PMIX_CLI_VERSION, PMIX_ARG_NONE, 'V'),
+    PMIX_OPTION_SHORT_DEFINE(PMIX_CLI_VERBOSE, PMIX_ARG_NONE, 'v'),
 
-pmix_ps_globals_t pmix_ps_globals = {
-    .help = false,
-    .parseable = false,
-    .nodes = false,
-    .nspace = NULL,
-    .pid = 0
+    PMIX_OPTION_DEFINE(PMIX_CLI_SYS_SERVER_FIRST, PMIX_ARG_NONE),
+    PMIX_OPTION_DEFINE(PMIX_CLI_SYSTEM_SERVER, PMIX_ARG_NONE),
+    PMIX_OPTION_DEFINE(PMIX_CLI_WAIT_TO_CONNECT, PMIX_ARG_REQD),
+    PMIX_OPTION_DEFINE(PMIX_CLI_NUM_CONNECT_RETRIES, PMIX_ARG_REQD),
+    PMIX_OPTION_DEFINE(PMIX_CLI_PID, PMIX_ARG_REQD),
+    PMIX_OPTION_DEFINE(PMIX_CLI_NAMESPACE, PMIX_ARG_REQD),
+    PMIX_OPTION_DEFINE(PMIX_CLI_URI, PMIX_ARG_REQD),
+    PMIX_OPTION_DEFINE("nodes", PMIX_ARG_NONE),
+    PMIX_OPTION_DEFINE(PMIX_CLI_TMPDIR, PMIX_ARG_REQD),
+
+    PMIX_OPTION_END
 };
-
-pmix_cmd_line_init_t cmd_line_opts[]
-    = {{NULL, 'h', NULL, "help", 0, &pmix_ps_globals.help, PMIX_CMD_LINE_TYPE_BOOL,
-        "This help message", PMIX_CMD_LINE_OTYPE_GENERAL},
-
-       {NULL, '\0', NULL, "parseable", 0, &pmix_ps_globals.parseable, PMIX_CMD_LINE_TYPE_BOOL,
-        "Provide parseable output", PMIX_CMD_LINE_OTYPE_GENERAL},
-
-       {NULL, '\0', NULL, "nspace", 0, &pmix_ps_globals.nspace, PMIX_CMD_LINE_TYPE_STRING,
-        "Nspace of job whose status is being requested", PMIX_CMD_LINE_OTYPE_GENERAL},
-
-       {NULL, 'p', NULL, "pid", 1, &pmix_ps_globals.pid, PMIX_CMD_LINE_TYPE_INT,
-        "Specify pid of launcher to be contacted (default is to system server", PMIX_CMD_LINE_OTYPE_GENERAL},
-
-       {NULL, 'n', NULL, "nodes", 0, &pmix_ps_globals.nodes, PMIX_CMD_LINE_TYPE_BOOL,
-        "Display Node Information", PMIX_CMD_LINE_OTYPE_GENERAL},
-
-       /* End of list */
-       {NULL, '\0', NULL, NULL, 0, NULL, PMIX_CMD_LINE_TYPE_NULL, NULL, PMIX_CMD_LINE_OTYPE_GENERAL}
-    };
+static char *ppsshorts = "h::vV";
 
 /* this is a callback function for the PMIx_Query
  * API. The query will callback with a status indicating
@@ -229,21 +209,25 @@ int main(int argc, char *argv[])
     size_t nq;
     myquery_data_t myquery_data;
     mylock_t mylock;
-    pmix_cmd_line_t cmd_line;
+    pmix_cli_result_t results;
+    PMIX_HIDE_UNUSED_PARAMS(argc);
 
     /* protect against problems if someone passes us thru a pipe
      * and then abnormally terminates the pipe early */
     signal(SIGPIPE, SIG_IGN);
 
+    /* init globals */
+    pmix_tool_basename = "pps";
+
     /* initialize the output system */
     if (!pmix_output_init()) {
         return PMIX_ERROR;
     }
 
     /* initialize install dirs code */
-    if (PMIX_SUCCESS
-        != (rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
-                                              PMIX_MCA_BASE_OPEN_DEFAULT))) {
+    rc = pmix_mca_base_framework_open(&pmix_pinstalldirs_base_framework,
+                                      PMIX_MCA_BASE_OPEN_DEFAULT);
+    if (PMIX_SUCCESS != rc) {
         fprintf(stderr,
                 "pmix_pinstalldirs_base_open() failed -- process will likely abort (%s:%d, "
                 "returned %d instead of PMIX_SUCCESS)\n",
@@ -259,7 +243,7 @@ int main(int argc, char *argv[])
     }
 
     /* initialize the help system */
-    pmix_show_help_init();
+    pmix_show_help_init(NULL);
 
     /* keyval lex-based parser */
     if (PMIX_SUCCESS != (rc = pmix_util_keyval_parse_init())) {
@@ -280,30 +264,18 @@ int main(int argc, char *argv[])
     }
 
     /* Parse the command line options */
-    pmix_cmd_line_create(&cmd_line, cmd_line_opts);
-
-    pmix_mca_base_open();
-    pmix_mca_base_cmd_line_setup(&cmd_line);
-    rc = pmix_cmd_line_parse(&cmd_line, false, false, argc, argv);
+    PMIX_CONSTRUCT(&results, pmix_cli_result_t);
+    rc = pmix_cmd_line_parse(argv, ppsshorts, ppsoptions,
+                             NULL, &results, "help-pps.txt");
 
     if (PMIX_SUCCESS != rc) {
-        if (PMIX_ERR_SILENT != rc) {
+        if (PMIX_ERR_SILENT != rc && PMIX_OPERATION_SUCCEEDED != rc) {
             fprintf(stderr, "%s: command line error (%s)\n", argv[0], PMIx_Error_string(rc));
         }
-        return rc;
-    }
-
-    if (pmix_ps_globals.help) {
-        char *str, *args = NULL;
-        args = pmix_cmd_line_get_usage_msg(&cmd_line);
-        str = pmix_show_help_string("help-pps.txt", "usage", true, args);
-        if (NULL != str) {
-            printf("%s", str);
-            free(str);
+        if (PMIX_OPERATION_SUCCEEDED == rc) {
+            rc = PMIX_SUCCESS;
         }
-        free(args);
-        /* If we show the help message, that should be all we do */
-        exit(0);
+        exit(rc);
     }
 
     /* if we were given the pid of a starter, then direct that
@@ -407,7 +379,7 @@ static int pretty_print_nodes(pmix_node_t **nodes, pmix_std_cntr_t num_nodes) {
     pmix_std_cntr_t i;
 
     /*
-     * Caculate segment lengths
+     * Calculate segment lengths
      */
     len_name    = (int) strlen("Node Name");
     len_state   = (int) strlen("State");
@@ -488,7 +460,7 @@ static int pretty_print_jobs(pmix_job_t **jobs, pmix_std_cntr_t num_jobs) {
         jobstr = PMIX_JOBID_PRINT(job->jobid);
 
         /*
-         * Caculate segment lengths
+         * Calculate segment lengths
          */
         len_jobid  = strlen(jobstr);;
         len_state  = (int) (strlen(pmix_job_state_to_str(job->state)) < strlen("State") ?
@@ -560,7 +532,7 @@ static int pretty_print_vpids(pmix_job_t *job) {
     }
 
     /*
-     * Caculate segment lengths
+     * Calculate segment lengths
      */
     len_o_proc_name = (int)strlen("PMIX Name");
     len_proc_name   = (int)strlen("Process Name");
