@@ -34,8 +34,8 @@
 
 #include "src/class/pmix_object.h"
 #include "src/include/pmix_globals.h"
-#include "src/util/output.h"
-#include "src/util/printf.h"
+#include "src/util/pmix_output.h"
+#include "src/util/pmix_printf.h"
 
 static pmix_proc_t myproc;
 
