@@ -4,7 +4,7 @@
  *                         All rights reserved.
  * Copyright (c) 2016-2019 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -23,8 +23,8 @@
 
 #include "pmix_server.h"
 #include "src/include/pmix_globals.h"
-#include "src/util/error.h"
-#include "src/util/printf.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_printf.h"
 
 #include "cli_stages.h"
 #include "server_callbacks.h"
@@ -32,6 +32,7 @@
 #include "test_server.h"
 
 int my_server_id = 0;
+static uint32_t nsession = 0;
 
 server_info_t *my_server_info = NULL;
 pmix_list_t *server_list = NULL;
@@ -138,34 +139,32 @@ static void set_namespace(int local_size, int univ_size, int base_rank, char *na
 {
     size_t ninfo;
     pmix_info_t *info;
-    ninfo = 8;
+    ninfo = 9;
     char *regex, *ppn, *tmp;
     char *ranks = NULL, **nodes = NULL;
     char **rks = NULL;
     int i;
     int rc;
+    uint32_t value;
 
     PMIX_INFO_CREATE(info, ninfo);
-    pmix_strncpy(info[0].key, PMIX_UNIV_SIZE, PMIX_MAX_KEYLEN);
-    info[0].value.type = PMIX_UINT32;
-    info[0].value.data.uint32 = univ_size;
+    PMIX_INFO_LOAD(&info[0], PMIX_SESSION_ID, &nsession, PMIX_UINT32);
+    ++nsession;
 
-    pmix_strncpy(info[1].key, PMIX_SPAWNED, PMIX_MAX_KEYLEN);
-    info[1].value.type = PMIX_UINT32;
-    info[1].value.data.uint32 = 0;
+    PMIX_INFO_LOAD(&info[1], PMIX_UNIV_SIZE, &univ_size, PMIX_UINT32);
 
-    pmix_strncpy(info[2].key, PMIX_LOCAL_SIZE, PMIX_MAX_KEYLEN);
-    info[2].value.type = PMIX_UINT32;
-    info[2].value.data.uint32 = local_size;
+    value = 0;
+    PMIX_INFO_LOAD(&info[2], PMIX_SPAWNED, &value, PMIX_UINT32);
+
+    value = local_size;
+    PMIX_INFO_LOAD(&info[3], PMIX_LOCAL_SIZE, &value, PMIX_UINT32);
 
     /* generate the array of local peers */
     fill_seq_ranks_array(local_size, base_rank, &ranks);
     if (NULL == ranks) {
         return;
     }
-    pmix_strncpy(info[3].key, PMIX_LOCAL_PEERS, PMIX_MAX_KEYLEN);
-    info[3].value.type = PMIX_STRING;
-    info[3].value.data.string = strdup(ranks);
+    PMIX_INFO_LOAD(&info[4], PMIX_LOCAL_PEERS, ranks,PMIX_STRING);
 
     /* assemble the node and proc map info */
     if (1 == params->nservers) {
@@ -187,7 +186,7 @@ static void set_namespace(int local_size, int univ_size, int base_rank, char *na
             return;
         }
         free(tmp);
-        PMIX_INFO_LOAD(&info[4], PMIX_NODE_MAP, regex, PMIX_REGEX);
+        PMIX_INFO_LOAD(&info[5], PMIX_NODE_MAP, regex, PMIX_REGEX);
     }
 
     /* generate the global proc map - if we have two
@@ -220,16 +219,14 @@ static void set_namespace(int local_size, int univ_size, int base_rank, char *na
     }
     PMIx_generate_ppn(ranks, &ppn);
     free(ranks);
-    PMIX_INFO_LOAD(&info[5], PMIX_PROC_MAP, ppn, PMIX_REGEX);
+    PMIX_INFO_LOAD(&info[6], PMIX_PROC_MAP, ppn, PMIX_REGEX);
     free(ppn);
 
-    pmix_strncpy(info[6].key, PMIX_JOB_SIZE, PMIX_MAX_KEYLEN);
-    info[6].value.type = PMIX_UINT32;
-    info[6].value.data.uint32 = univ_size;
+    value = univ_size;
+    PMIX_INFO_LOAD(&info[7], PMIX_JOB_SIZE, &value, PMIX_UINT32);
 
-    pmix_strncpy(info[7].key, PMIX_APPNUM, PMIX_MAX_KEYLEN);
-    info[7].value.type = PMIX_UINT32;
-    info[7].value.data.uint32 = getpid();
+    value = getpid();
+    PMIX_INFO_LOAD(&info[8], PMIX_APPNUM, &value, PMIX_UINT32);
 
     int in_progress = 1;
     if (PMIX_SUCCESS
@@ -849,14 +846,23 @@ int server_init(test_params *params)
 
         TEST_VERBOSE(("pmix server %d started PID:%d", my_server_id, getpid()));
         for (i = params->nservers - 1; i >= 0; i--) {
+            int ret;
             pid_t pid;
             server_info = PMIX_NEW(server_info_t);
 
             int fd1[2];
             int fd2[2];
 
-            pipe(fd1);
-            pipe(fd2);
+            ret = pipe(fd1);
+            if (ret != 0) {
+                TEST_ERROR(("pipe failed"));
+                return -1;
+            }
+            ret = pipe(fd2);
+            if (ret != 0) {
+                TEST_ERROR(("pipe failed"));
+                return -1;
+            }
 
             if (0 != i) {
                 pid = fork();
