@@ -4,9 +4,9 @@
  *                         All rights reserved.
  * Copyright (c) 2016-2019 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
- * Copyright (c) 2020-2021 Triad National Security, LLC
+ * Copyright (c) 2020-2022 Triad National Security, LLC
  *                         All rights reserved.
- * Copyright (c) 2021      Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -25,8 +25,8 @@
 
 #include "pmix_server.h"
 #include "src/include/pmix_globals.h"
-#include "src/util/error.h"
-#include "src/util/printf.h"
+#include "src/util/pmix_error.h"
+#include "src/util/pmix_printf.h"
 
 #include "cli_stages.h"
 #include "server_callbacks.h"
@@ -734,6 +734,7 @@ int server_barrier(void)
     msg_hdr.src_id = my_server_id;
     msg_hdr.size = 0;
     // setting nprocs to 0 indicates that all procs participate
+    memset(msg_hdr.procs, 0, sizeof(msg_hdr.procs));
     msg_hdr.nprocs = 0;
 
     server->lock.active = true;
@@ -760,7 +761,7 @@ static void server_read_cb(int fd, short event, void *arg)
     msg_hdr_t msg_hdr;
     char *msg_buf = NULL;
     static char *fence_buf = NULL;
-    int i, n, p, temp_nodeid, fence_idx=0, rc;
+    int i, n, p, temp_nodeid = -1, fence_idx=0, rc;
     static int fences_in_flight = 0;
     bool fence_found = false, node_found = false;
     // hard limits to fences in flight, procs, and nodes below
